<?php
/**
 * @package		EasyBlog
 * @copyright	Copyright (C) 2010 Stack Ideas Private Limited. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 *  
 * EasyBlog is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See COPYRIGHT.php for copyright notices and details.
 */

defined('_JEXEC') or die('Restricted access');

require_once( JPATH_ROOT . DS . 'components' . DS . 'com_easyblog' . DS . 'constants.php' );
require_once( EBLOG_CLASSES . DS . 'facebook' . DS . 'consumer.php' );

class EasyBlogFacebook extends Facebook
{
	var $callback		= '';
	var $_access_token	= '';
	
	public function __construct( $key , $secret , $callback )
	{
		$this->callback	= $callback;

		parent::__construct( array( 'appId' 	=> $key ,
									'secret'	=> $secret,
									'cookie'	=> true
							) 
		);
	}
	
	/**
	 * Facebook does not need the request tokens
	 * 
	 **/	 	 	
	public function getRequestToken()
	{
		$obj		= new stdClass();
		$obj->token		= 'facebook';
		$obj->secret	= 'facebook';
		
		return $obj;
	}

	/**
	 * Returns the verifier option. Since Facebook does not have oauth_verifier,
	 * The only way to validate this is through the 'code' query
	 * 
	 * @return string	$verifier	Any string representation that we can verify it isn't empty.	 	 
	 **/	 	 	
	public function getVerifier()
	{
		$verifier	= JRequest::getVar( 'code' , '' );
		return $verifier;
	}

	/**
	 * Returns the authorization url.
	 * 
	 * @return string	$url	A link to Facebook's login URL.	 	 
	 **/
	public function getAuthorizationURL( $token )
	{
		$scope	= array( 
							'publish_stream',
							'user_likes',
							'user_about_me',
							'user_birthday',
							'offline_access',
							'manage_pages',
							'user_hometown',
							'user_location',
							'user_relationships',
							'user_status',
							'email',
							'read_friendlists',
							'user_checkins'
						);
		$url	= 'http://facebook.com/dialog/oauth?scope=' . implode( ',' , $scope ) . '&client_id=' . parent::getAppId() . '&redirect_uri=' . urlencode( $this->callback ) . '&response_type=code';

		return $url;
	}
	
	public function getAccess( $token , $secret , $verifier )
	{
		$code		= JRequest::getVar( 'code' );
		$params		= array( 'client_id' 	=> parent::getAppId() ,
							 'redirect_uri'	=> $this->callback,
							 'client_secret'=> parent::getApiSecret(),
							 'code'			=> $code
							);

		$token		= parent::_oauthRequest( parent::getUrl('graph', '/oauth/access_token' ) , $params );
		$token		= str_ireplace( 'access_token=' , '' , $token );
		$obj		= new stdClass();
		$obj->token	= $token;
		$obj->secret= 'facebook';
		
		return $obj;
	}
	
	/**
	 * Shares a new content on Facebook
	 **/	 	 	
	public function share( $blog , $message = '' , $private = true , $twitter = false )
	{
		$pattern	= '/<\s*img [^\>]*src\s*=\s*[\""\']?([^\""\'\s>]*)/i';
		preg_match( $pattern , $blog->content , $matches );
		
		$image		= '';

		if( $matches )
		{
			$image		= isset( $matches[1] ) ? $matches[1] : '';

			if( JString::stristr( 'http://' , $matches[1] ) === false && !empty( $image ) )
			{
				$image	= JURI::root() . $image;
			}
		}
		
		$config			= EasyBlogHelper::getConfig();
		$maxContentLen  = $config->get( 'integrations_facebook_blogs_length' );

		$text		= strip_tags( $blog->content );
		if( !empty( $maxContentLen ) )
		{
		    $text       = ( JString::strlen( $text ) > $maxContentLen ) ? JString::substr( $text, 0, $maxContentLen) . '...' : $text;
		}
		
		$url		= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&view=entry&id=' . $blog->id , false , true );

		$jConfig	= JFactory::getConfig();
		$params		= array( 
							'link' 			=>  $url, 
							'picture' 		=> $image ,
							'name'			=> $blog->title,
							'actions'		=> '{"name": "' . JText::sprintf( 'COM_EASYBLOG_INTEGRATIONS_FACEBOOK_VIEWON_BUTTON' , $jConfig->getValue( 'sitename' ) ) . '", "link" : "' . $url . '"}',
							'description' 	=> $text,
							'access_token' 	=> $this->_access_token
							);

		// For centralized statuses, we need to ensure that the account is posted to the page id.
		if( $config->get( 'integrations_facebook_page_id' ) && $config->get( 'integrations_facebook_centralized' ) )
		{
			$pageId	= JString::trim( $config->get( 'integrations_facebook_page_id' ) );
			
			if( $config->get( 'integrations_facebook_impersonate_page' ) )
			{
				// Retrieve the list of user apps first.
				$apps	= parent::api( '/me/accounts' , array( 'access_token' => $this->_access_token) );
				
				if( is_array( $apps ) && isset( $apps['data'] ) )
				{
					foreach( $apps[ 'data' ] as $item )
					{
						// Impersonate as the page author.
						if( $item[ 'id' ] == $pageId )
						{
							$params[ 'access_token' ]	= $item[ 'access_token' ];
						}
					}
					 
				}
			}
			
			$query		= parent::api( '/' . $pageId . '/feed' , 'post' , $params );
		}
		else
		{
			$query		= parent::api( '/me/feed' , 'post' , $params );
		}
		$success	= isset( $query['id'] ) ? true : false;
		
		return $success;
	}
	
	public function setAccess( $access )
	{
		$access	= new JParameter( $access );
		
		$this->_access_token	= $access->get( 'token' );
		return true;
	}
	
	public function revokeApp()
	{
		return true;
	}
}