<?php
/**
 * @package		EasyBlog
 * @copyright	Copyright (C) 2010 Stack Ideas Private Limited. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 *
 * EasyBlog is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See COPYRIGHT.php for copyright notices and details.
 */
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.controller');
require_once( EBLOG_HELPERS . DS . 'loader.php' );
require_once( EBLOG_HELPERS . DS . 'helper.php' );

class EasyBlogController extends JController
{
	/**
	 * Constructor
	 *
	 * @since 0.1
	 */
	function __construct()
	{
		// Load necessary css and javascript files.
		EasyBlogHelper::loadHeaders();
		
		// By default, we use the tables specified at the back end.
		JTable::addIncludePath( JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_easyblog' . DS . 'tables');
		
		//load the content plugins so that the content trigger will work.
		JPluginHelper::importPlugin('content');

		parent::__construct();
	}

	/**
	 * Override parent's display method
	 *
	 * @since 0.1
	 */
	function display( $cachable = false )
	{
		$document	=& JFactory::getDocument();

		$viewName	= JRequest::getCmd( 'view', $this->getName() );
		
		if( $viewName == 'easyblog' )
		{
			$viewName	= 'latest';
		}
		
		if($viewName != 'entry')
		{
		    EasyBlogHelper::clearSession('EASYBLOG_TEAMBLOG_ID');
		}
		
		$viewLayout	= JRequest::getCmd( 'layout', 'default' );
		$view		= & $this->getView( $viewName, $document->getType() , '' );
 		$format		= JRequest::getCmd( 'format' , 'html' );
 		$tmpl		= JRequest::getCmd( 'tmpl' , 'html' );
		
 		if( !empty( $format ) && $format == 'ejax' )
 		{
			if( ob_get_length() !== false )
   			{
    			while (@ ob_end_clean());
				if( function_exists( 'ob_clean' ) )
				{
					@ob_clean();
				}
			}
			
			// Ajax calls.
			if(!JRequest::checkToken( 'GET' ) )
			{
				$ejax	= new Ejax();
				$ejax->script( 'alert("' . JText::_('Not allowed here') . '");' );
				$ejax->send();
			}
			
			$data		= JRequest::get( 'POST' , JREQUEST_ALLOWHTML );
			$arguments	= array();

			foreach( $data as $key => $value )
			{
				if( JString::substr( $key , 0 , 5 ) == 'value' )
				{
				    if(is_array($value))
				    {
				        $arrVal    = array();
						foreach($value as $val)
						{
						    $item   =& $val;
						    $item   = stripslashes($item);
						    $item   = rawurldecode($item);
						    $arrVal[]   = $item;
						}
						$arrVal			= EasyBlogStringHelper::ejaxPostToArray( $arrVal );
                        $arguments[]	= $arrVal;
				    }
					else
					{
						$val			= stripslashes( $value );
						$val			= rawurldecode( $val );
						$arguments[]	= $val;
					}
				}
			}

			if(!method_exists( $view , $viewLayout ) )
			{
				$ejax	= new Ejax();
				$ejax->script( 'alert("' . JText::sprintf( 'Method %1$s does not exists in this context' , $viewLayout ) . '");');
				$ejax->send();

				return;
			}

			// Execute method
			call_user_func_array( array( $view , $viewLayout ) , $arguments );
		}
		else
		{
			$config 	=& EasyBlogHelper::getConfig();
			$theme 		= $config->get( 'layout_theme' );
			$dashboard	= $viewName == 'dashboard';
			
			EasyBlogHelper::loadThemeCss( 'styles.css' , $dashboard );
			
			
			jimport( 'joomla.filesystem.file' );
			
			
			$mainframe =& JFactory::getApplication();
			
			// If there is any override through the query string, we need to set it here.
			$overrides	= JRequest::getString( 'theme' , '' );
			
			if( !empty( $overrides ) )
			{
				$theme	= $overrides;
			}

			// @rule: Use Google fonts if necessary.
			$headingFont	= $config->get( 'layout_googlefont' );
			if(  $headingFont != 'site' )
			{
				$headingFont	= explode( ' ' , $headingFont );
				$headingFont	= JString::strtolower( $headingFont[0] );
			}
			
			// @task: Set the wrapper.
			echo '<div id="eblog-wrapper" class="eblog-' . $theme . ' eblog-' . $headingFont . '">';
						
			$print = JRequest::getBool('print');

			if( $config->get( 'integrations_jomsocial_toolbar' ) && $format != 'pdf' && $tmpl != 'component' )
			{
				if(JFile::exists(JPATH_ROOT . DS . 'components' . DS. 'com_community' . DS . 'libraries' . DS .'core.php'))
				{
					require_once( JPATH_ROOT . DS . 'components' . DS. 'com_community' . DS . 'libraries' . DS .'core.php' );
					require_once( JPATH_ROOT . DS . 'components' . DS. 'com_community' . DS . 'libraries' . DS .'toolbar.php' );

					$appsLib	=& CAppPlugins::getInstance();
					$appsLib->loadApplications();

					$appsLib->triggerEvent( 'onSystemStart' , array() );

					echo '<div id="community-wrap">';

					echo CToolbarLibrary::getHTML();
				}
			}

			if( !$print && $format != 'pdf' && $tmpl != 'component' )
			{
				if( $view->getName() == 'dashboard' && $config->get( 'layout_dashboard_show_headers' ) )
				{
					echo $this->getToolbar( $view->getName() );
				}
				
				if( $view->getName() != 'dashboard' )
				{
					echo $this->getToolbar( $view->getName() );
				}
			}
			
			$messages	= EasyBlogHelper::getMessageQueue();
			
			if( !empty( $messages ) )
			{
			?>
			<div class="eblog-message <?php echo $messages->type;?>">
				<p><?php echo $messages->message;?></p>
			</div>
			<?php
			}

			// @task: Set additional wrapper for dashboard views
			if( JRequest::getVar( 'view' ) == 'dashboard' )
			{
				echo '<div id="ezblog-dashboard">'; 
			}
			
			if( $viewLayout != 'default' )
			{
				if( $cachable )
				{
					$cache	=& JFactory::getCache( 'com_easyblog' , 'view' );
					$cache->get( $view , $viewLayout );
				}
				else
				{
					
					if( !method_exists( $view , $viewLayout ) )
					{
						$view->display();
					}
					else
					{
						$view->$viewLayout();
					}
				}
			}
			else
			{
				$view->display();
			}

			// @task: Close additional wrapper for dashboard views
			if( JRequest::getVar( 'view' ) == 'dashboard' )
			{
				echo '</div>'; 
			}

			if( $config->get( 'integrations_jomsocial_toolbar' ) )
			{
				echo '</div>';
			}

			// Close outer wrapper
			echo '</div>';
		}
		
		//print powered by start
		echo EBLOG_POWERED_BY_LINK;
		//print powered by end
	}

	function getToolbar( $viewName )
	{
		static $toolbar = null;

		require_once( EBLOG_HELPERS . DS . 'helper.php' );

		if( is_null( $toolbar ) )
		{
			// Set active menu.
			$views	= array( 'home' => 'item' , 'blogger' => 'item', 'blogroll' => 'item', 'tags' => 'item', 'categories' => 'item', 'dashboard' => 'item', 'teamblog' => 'item' , 'archive' => 'item' , 'search' => 'item' );
			$views	= (object) $views;

			if( isset( $views->$viewName ) )
			{
				$views->$viewName	= 'item-active';
			}
			else
			{
				// View does not exist, so we set the default 'latest' to be active.
				$views->home		= 'item-active';
			}

			$config			=& EasyBlogHelper::getConfig();

			$tpl	= new CodeThemes();

			$title	= $config->get( 'main_title' );
			$desc	= $config->get( 'main_description' );
			$bloggerId	= JRequest::getInt( 'id' , '' );
			$blogger	= JRequest::getVar( 'blogger' , '' );
			
			$isBloggerMode	= EasyBlogRouter::isBloggerMode();
			
			if( !empty( $blogger ) )
			{
				$bloggerId	= $blogger;
			}
			
			if( $isBloggerMode !== false)
			{
			    $bloggerId	= $isBloggerMode;
			}
			
			if( ( ($viewName == 'blogger' || !empty($blogger) ) && !empty( $bloggerId ) ) ||  ($isBloggerMode !== false) )
			{
			   $blogger   =& JTable::getInstance( 'Blogger' , 'Table' );
			   $blogger->load( $bloggerId );
			
			   $title      = !empty($blogger->title)? $blogger->title : $title ;
			   $desc      = !empty($blogger->description)? $blogger->description : $desc;
			}
    
			$teamId      = JRequest::getInt( 'id' , 0 );         
			if( $viewName == 'teamblog' && !empty( $teamId ) )
			{
				$team   =& JTable::getInstance( 'TeamBlog' , 'Table' );
				$team->load( $teamId );
				
				$title		= !empty($team->title)? $team->title : $title ;
				$desc		= !empty($team->description)? $team->description : $desc;
			}
			
			$joomlaVersion	= EasyBlogHelper::getJoomlaVersion();
			$logoutURL		= base64_encode( EasyBlogRouter::_('index.php?option=com_easyblog&view=latest' , false ) );

			$isTeamAdmin    	= EasyBlogHelper::isTeamAdmin();
			$totalTeamRequest   = 0;

			if($isTeamAdmin)
			{
			    $teamModel =& $this->getModel('TeamBlogs');
			    $totalTeamRequest	= $teamModel->getTotalRequest();
			}
			
			$my	=& JFactory::getUser();
			$totalModComment    = 0;
			if( $my->id > 0)
			{
				$commentModel 		=& $this->getModel('Comment');
				$totalModComment   	= $commentModel->getUserModerateCommentCount($my->id);
			}

			$tpl->set( 'title'		, $title );
			$tpl->set( 'desc'		, $desc );
			$tpl->set( 'views' 		, $views );
			$tpl->set( 'isLoggedIn' , EasyBlogHelper::isLoggedIn() );
			$tpl->set( 'logoutURL' 			, $logoutURL );
			$tpl->set( 'isTeamAdmin' 		, $isTeamAdmin );
			$tpl->set( 'totalTeamRequest'	, $totalTeamRequest );
			$tpl->set( 'totalModComment'	, $totalModComment );
			$toolbar	= $tpl->fetch( 'toolbar.php' );

			unset( $tpl );
		}
		return $toolbar;
	}

	/**
	 * Overrides parent method
	 **/
	public static function getInstance( $controllerName )
	{
		static $instances;

		if( !$instances )
		{
			$instances	= array();
		}

		// Set the controller name
		$className	= 'EasyBlogController' . ucfirst( $controllerName );

		if( !isset( $instances[ $className ] ) )
		{
			if( !class_exists( $className ) )
			{
				jimport( 'joomla.filesystem.file' );
				$controllerFile	= EBLOG_CONTROLLERS . DS . JString::strtolower( $controllerName ) . '.php';

				if( JFile::exists( $controllerFile ) )
				{
					require_once( $controllerFile );

					if( !class_exists( $className ) )
					{
						// Controller does not exists, throw some error.
						JError::raiseError( '500' , JText::sprintf('Controller %1$s not found' , $className ) );
					}
				}
				else
				{
					// File does not exists, throw some error.
					JError::raiseError( '500' , JText::sprintf('Controller %1$s.php not found' , $controllerName ) );
				}
			}

			$instances[ $className ]	= new $className();
		}
		return $instances[ $className ];
	}

}