<?php
/**
 * @package		EasyBlog
 * @copyright	Copyright (C) 2010 Stack Ideas Private Limited. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 *  
 * EasyBlog is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See COPYRIGHT.php for copyright notices and details.
 */

defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.controller');
require_once( EBLOG_HELPERS . DS . 'helper.php' );
require_once( EBLOG_HELPERS . DS . 'oauth.php' );
require_once( EBLOG_HELPERS . DS . 'subscription.php' );

class EasyBlogControllerDashboard extends JController
{
	/**
	 * Constructor
	 *
	 * @since 0.1
	 */
	function __construct()
	{
		// Include the tables in path
		JTable::addIncludePath( EBLOG_TABLES );
		
		parent::__construct();
	}

	/**
	 * Display the view
	 * 
	 * @since 0.1
	 */
	function display()
	{
		$document	=& JFactory::getDocument();
		$viewType	= $document->getType();
		$viewName	= JRequest::getCmd( 'view', $this->getName() );
		$view 		= & $this->getView( $viewName,'',  $viewType);		
		$view->display();
	}
	
	function toggleBlogStatus()
	{
	
		$mainframe	=& JFactory::getApplication();
	    $acl		= EasyBlogACLHelper::getRuleSet();
	    $url    	= 'index.php?option=com_easyblog&view=latest';
	    $msgType    = 'info';
		$id 		= JRequest::getVar( 'blogId' , '' );
		$id 		= explode( "," , $id );
		$src    	= JRequest::getVar( 'from' , '' );
		$src    	= strtolower($src);
		$status		= JRequest::getInt('status', 0);

		if( empty($acl->rules->publish_entry) )
		{
			$callback = JText::_('COM_EASYBLOG_NO_PERMISSION_TO_PUBLISH_OR_UNPUBLISH_BLOG');
			EasyBlogHelper::setMessageQueue( $callback , 'error');
			$mainframe->redirect(EasyBlogRouter::_($url, false));
			return;
		}
		
		JTable::addIncludePath( EBLOG_TABLES );
		foreach( $id as $data )
		{
			$blog		= JTable::getInstance( 'Blog' , 'Table' );
			$blog->load( $data );

			if( $blog->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
			{
				$callback	= JText::_('COM_EASYBLOG_NO_PERMISSION_TO_PUBLISH_OR_UNPUBLISH_BLOG');
				EasyBlogHelper::setMessageQueue( $callback , 'error');
				$mainframe->redirect( EasyBlogRouter::_( $url , false ) );
				return;
			}
		}

		$model		=& $this->getModel( 'Blogs' );
		$result 	= $model->publish($id, $status);

		$msg		= '';
		if($result)
		{
			$callback 	= ($status) ? JText::_('COM_EASYBLOG_DASHBOARD_ENTRIES_PUBLISHED_SUCCESS') : JText::_('COM_EASYBLOG_DASHBOARD_ENTRIES_UNPUBLISHED_SUCCESS');
			$msgType    = 'info';
		}
		else
		{
		    $callback 	= JText::_('COM_EASYBLOG_DASHBOARD_ENTRIES_STATUS_FAILED_TO_UPDATE');
		    $msgType    = 'warning';
		}
		
		
		EasyBlogHelper::setMessageQueue( $callback , $msgType);
		switch($src)
		{
			case 'categories':
			    $url    = 'index.php?option=com_easyblog&view=categories';
			    break;
			case 'category':
			    $catId  = JRequest::getInt('catId', '1'); // default show uncategories
			    $url    = 'index.php?option=com_easyblog&view=categories&layout=listings&id='.$catId;
			    break;
			case 'tag':
			    $tagId  = JRequest::getInt('tagId', '0');
			    $url    = 'index.php?option=com_easyblog&view=tags&layout=tag&id='.$tagId;
			    break;
			case 'blogger':
				$bloggerId  = JRequest::getInt('bloggerId', '0');
				$extra      = (empty($bloggerId)) ? '' : '&layout=listings&id=' . $bloggerId;
			    $url    = 'index.php?option=com_easyblog&view=blogger' . $extra;
			    break;
			case 'archive':
			    $archiveyear 	= JRequest::getInt('archiveyear', '0');
			    $archivemonth 	= JRequest::getInt('archivemonth', '0');
			    $url    = 'index.php?option=com_easyblog&view=archive&archiveyear='.$archiveyear.'&archivemonth='.$archivemonth;
			    break;
			case 'eblog':
			default:
			    $url    = 'index.php?option=com_easyblog&view=latest';
			    break;
		}

		$mainframe->redirect(EasyBlogRouter::_($url, false));
	}
	

	function deleteTag()
	{
		$mainframe	=& JFactory::getApplication();
		$config     =& EasyBlogHelper::getConfig();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$callback 	= "";
		$url    	= 'index.php?option=com_easyblog&view=dashboard&layout=tags';
		$msgType    = 'info';
		$tags       = JRequest::getVar('tagId','');
		$my			= JFactory::getUser();
		
		if($acl->rules->create_tag)
		{
			$id = explode(",", $tags);

			if( empty( $tags ) )
			{
				$callback	= JText::_('COM_EASYBLOG_TAG_INVALID_ID');
				$msgType    = 'error';
			}
			else
			{
				$table		=& JTable::getInstance( 'Tag' , 'Table' );
				foreach( $id as $data )
				{
				    $isError    = false;
					$table->load( $data );

					if( $table->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
					{
						EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error');
						$mainframe->redirect( EasyBlogRouter::_( $url , false ) );
						return;
					}
					
					if($table->deletePostTag())
					{
						if( !$table->delete() )
						{
							$isError    = true;
						}
						else
						{
							if( $table->created_by != 0 && $config->get('main_jomsocial_userpoint') )
							{
								$jsUserPoint	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
								if( JFile::exists( $jsUserPoint ) )
								{
									require_once( $jsUserPoint );
									CUserPoints::assignPoint( 'com_easyblog.tag.remove' , $table->created_by );
								}
							}
							
							// AlphaUserPoints
							// since 1.2
							if ( $table->created_by != 0 && EasyBlogHelper::isAUPEnabled() )
							{
								$aupid = AlphaUserPointsHelper::getAnyUserReferreID( $table->created_by );
								AlphaUserPointsHelper::newpoints( 'plgaup_easyblog_delete_tag', $aupid, '', JText::sprintf('COM_EASYBLOG_AUP_TAG_DELETED', $table->title) );
							}
							
						}
					}
					else
					{
					    $isError    = true;
					}
					
					if($isError)
					{
						$callback = JText::sprintf('ERROR REMOVING TAG POST', $table->id, $table->title).'<br />';
						EasyBlogHelper::setMessageQueue( $callback , 'error');
						$mainframe->redirect(EasyBlogRouter::_($url, false));
					}

				}

				$callback = JText::_('COM_EASYBLOG_TAG_DELETED');
			}
		}
		else
		{
			$callback	= JText::_('COM_EASYBLOG_NO_PERMISSION_TO_DELETE_TAG');
			$msgType    = 'warning';
		}

		//returned message
		EasyBlogHelper::setMessageQueue( $callback , $msgType);
		$mainframe->redirect(EasyBlogRouter::_($url, false));
	}

	/*
	 * Responsible to delete comments
	 * @param	null
	 * @return	null
	 */	 
	public function deleteComments()
	{
	    $mainframe  =& JFactory::getApplication();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$my			= JFactory::getUser();
		$redirect	= base64_decode( JRequest::getVar( 'redirect' , '' ) );
		$redirect	= empty( $redirect ) ? EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=categories' , false ) : EasyBlogRouter::_( $redirect , false );
		$my			= JFactory::getUser();
		$ids		= JRequest::getVar( 'id' , '' );
		$ids		= explode( ',' , $ids );

		if( empty($acl->rules->delete_comment) || $my->id == 0 )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_DELETE_COMMENT') , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}

		JTable::addIncludePath( EBLOG_TABLES );
		foreach ($ids as $id)
		{
			$comment	= JTable::getInstance( 'Comment' , 'Table' );
			$comment->load( $id );
			
			// @rule: Check if the current browser is the author of the blog.
			$blog		= JTable::getInstance( 'Blog' , 'Table' );
			$blog->load( $comment->post_id );
			
			if( $blog->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
			{
				EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_NOT_ALLOWED') , 'error' );
				$mainframe->redirect( $redirect );
				$mainframe->close();
			}

			// @since 1.2
			// AlphaUserPoints
			if ( !empty($comment->created_by) && EasyBlogHelper::isAUPEnabled() )
			{
				AlphaUserPointsHelper::newpoints( 'plgaup_easyblog_delete_comment', AlphaUserPointsHelper::getAnyUserReferreID( $comment->created_by ) , '', JText::_('COM_EASYBLOG_AUP_COMMENT_DELETED') );
			}
			$comment->delete($cid);
		}

		EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_COMMENTS_DELETED_SUCCESS') , 'success');
		$mainframe->redirect( $redirect );
		$mainframe->close();
	}
	
	/*
	 * Responsible to delete category
	 * @param	null
	 * @return	null
	 */	 
	function deleteCategory()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$mainframe  =& JFactory::getApplication();
		$config     =& EasyBlogHelper::getConfig();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$redirect	= base64_decode( JRequest::getVar( 'redirect' , '' ) );
		$redirect	= empty( $redirect ) ? EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=categories' , false ) : EasyBlogRouter::_( $redirect , false );
		$my			= JFactory::getUser();
		$id			= JRequest::getVar('categoryId','');

		if( !$acl->rules->delete_category || $my->id == 0 )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_DELETE_CATEGORY') , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}

		if( empty( $id ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_CATEGORIES_ID_IS_EMPTY_ERROR' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		JTable::addIncludePath( EBLOG_TABLES );		
		$category	= JTable::getInstance( 'ECategory' , 'Table' );
		$category->load( $id );
		
		if( $category->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error');
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}

		if( $category->getPostCount() > 0 )
		{
			EasyBlogHelper::setMessageQueue(  JText::_( 'COM_EASYBLOG_DASHBOARD_CATEGORIES_POST_NOT_EMPTY_ERROR'  ) , 'error');
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}

		if( $category->getChildCount() > 0 )
		{
			EasyBlogHelper::setMessageQueue(  JText::_( 'COM_EASYBLOG_DASHBOARD_CATEGORIES_HAS_CHILD_ERROR'  ) , 'error');
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}					

		if( !$category->delete() )
		{
			EasyBlogHelper::setMessageQueue(  JText::sprintf( 'COM_EASYBLOG_DASHBOARD_CATEGORIES_DELETE_ERROR' , $category->title ) , 'error');
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}

		if( $category->created_by != 0 && $config->get('main_jomsocial_userpoint') )
		{
			$path	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
			if( JFile::exists( $path ) )
			{
				require_once( $path );
				CUserPoints::assignPoint( 'com_easyblog.category.remove' , $category->created_by );
			}
		}
		
		// @since 1.2
		// AlphaUserPoints
		if ( $category->created_by != 0 && EasyBlogHelper::isAUPEnabled() )
		{
			AlphaUserPointsHelper::newpoints( 'plgaup_easyblog_delete_category', AlphaUserPointsHelper::getAnyUserReferreID( $category->created_by ) , '', JText::sprintf('COM_EASYBLOG_AUP_CATEGORY_DELETED', $category->title) );
		}
		
		EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_CATEGORIES_DELETED_SUCCESSFULLY' ) , 'success' );
		$mainframe->redirect( $redirect );
		$mainframe->close();
	}
	
	/*
	 * Allows anyone to approve comments provided that they get the correct key
	 *
	 * @param	null
	 * @return	null
	 */
	public function approveComment()
	{
		$mainframe	= JFactory::getApplication();
		$key		= JRequest::getVar( 'key' , '' );
		$redirect	= EasyBlogRouter::_( 'index.php?option=com_easyblog' , false );
		
		if( empty( $key ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error');
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		JTable::addIncludePath( EBLOG_TABLES );
		$hashkey	= JTable::getInstance( 'HashKeys' , 'Table' );
		
		if( !$hashkey->loadByKey( $key ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error');
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		$comment	= JTable::getInstance( 'Comment' , 'Table');
		$comment->load( $hashkey->uid );
		$comment->published	= EBLOG_COMMENT_PUBLISHED;
		$comment->store();
		
		// Delete the unused hashkey now.
		$hashkey->delete();
		
		EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_MODERATE_COMMENT_PUBLISHED_SUCCESS' ) , 'success');
		$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=entry&id=' . $comment->post_id , false ) ); 
	}
	 
	/*
	 * Allows users with privileges to approve pending blog entries
	 *
	 * @param	null
	 * @return	null
	 */
	function approveBlog()
	{
		$mainframe	=& JFactory::getApplication();
		$config 	=& EasyBlogHelper::getConfig();
		$message	= '';
		$type		= 'message';
		
		$my			=& JFactory::getUser();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$joomlaVersion = EasyBlogHelper::getJoomlaVersion();

		if( empty( $acl->rules->add_entry ) && empty( $acl->rules->manage_pending ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_CREATE_BLOG') , 'warning');
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard' , false ) );
			return;
		}

		if( $my->id == 0 )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_YOU_ARE_NOT_LOGIN') , 'error' );
			$this->setRedirect( EasyBlogRouter::_( 'index.php?option=com_easyblog' , false ) );
		}

		if( JRequest::getMethod() != 'POST' )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_SAVE_INVALID_METHOD') , 'error' );
			$this->setRedirect( EasyBlogRouter::_( 'index.php?option=com_easyblog' , false ) );
		}

		JPluginHelper::importPlugin( 'easyblog' );
		$dispatcher =& JDispatcher::getInstance();


		$draft		=& JTable::getInstance( 'Draft', 'Table' );
		$id			= JRequest::getInt( 'ids' );
		$draft->load( $id );
		
		
		$blog		=& JTable::getInstance( 'blog', 'Table' );
		$isNew		= ( $blog->load( $draft->entry_id ) ) ? false : true;

		if(! $isNew)
		{
		    // if this is blog edit, then we should see the column isnew to determine
		    // whether we should send any notification
		    $isNew  = $blog->isnew;
		}


		// @task: Map the data from draft table.
		$blog->bind( $draft );
		$blog->set( 'id' , $draft->entry_id );
		
		//author acl
		$authorAcl		= EasyBlogACLHelper::getRuleSet( $blog->created_by );


		//check if user have permission to enable privacy.
		$blog->private	= empty( $authorAcl->rules->enable_privacy ) ? 0 : $blog->private;

		//check if user have permission to contribute the blog post to eblog frontpage
		$blog->frontpage 	= ( empty($authorAcl->rules->contribute_frontpage) ) ? '0' : $blog->frontpage;
		$blog->isnew 		= ($isNew && ($blog->published != 1)) ? '1' : '0';

		//now we need to check the blog contribution
		$blog->issitewide	= isset( $draft->blog_contribute) && $draft->blog_contribute != 0 ? false : true;
		
		$blogContribution   = array();
		$issitewide 		= '1';

		if( isset( $draft->blog_contribute) && $draft->blog_contribute == '0' )
		{
			$blog->issitewide	= true;
		}
		else
		{
			$blog->issitewide	= false;
			$blogContribution[]	= $draft->blog_contribute;
		}

		//onBeforeEasyBlogSave trigger start
		$blog->introtext	= '';
		$blog->text			= '';
		$dispatcher->trigger( 'onBeforeEasyBlogSave' , array( &$blog , $isNew ) );
		//onBeforeEasyBlogSave trigger end

		//onBeforeContentSave trigger start
		$blog->introtext	= $blog->intro;
		$blog->text			= $blog->content;

		if($joomlaVersion >= '1.6')
		{
			$dispatcher->trigger('onContentBeforeSave', array('easyblog.blog', &$blog, $isNew));
		}
		else
		{
			$dispatcher->trigger('onBeforeContentSave', array(&$blog, $isNew));
		}

		$blog->intro		= $blog->introtext;
		$blog->content		= $blog->text;
		unset($blog->introtext);
		unset($blog->text);
		//onBeforeContentSave trigger end
		
		if( !empty($draft->blogpassword) && !EasyBlogHelper::isFeatured( 'post' , $blog->id ) )
		{
			$blog->blogpassword = $draft->blogpassword;
		}
		
		if (!$blog->store())
		{
		    EasyBlogHelper::setMessageQueue( $blog->getError() , 'error');
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=write' , false) );
		}

		//onAfterEasyBlogSave trigger start
		$blog->introtext	= "";
		$blog->text			= "";
		$dispatcher->trigger('onAfterEasyBlogSave', array(&$blog, $isNew));
		//onAfterEasyBlogSave trigger end

		//onAfterContentSave trigger start
		$blog->introtext	= $blog->intro;
		$blog->text			= $blog->content;

		if($joomlaVersion >= '1.6')
		{
			$dispatcher->trigger('onContentAfterSave', array('easyblog.blog', &$blog, $isNew));
		}
		else
		{
			$dispatcher->trigger('onAfterContentSave', array(&$blog, $isNew));
		}

		$blog->excerpt		= $blog->introtext;
		$blog->content		= $blog->text;
		unset($blog->introtext);
		unset($blog->text);
		//onAfterContentSave trigger end

		// this variable will be use when sending notification. This is bcos
		// the currently login use might be the admin and editing other blogger post.
	    $authorId   = $blog->created_by;

        //now we update the blog contribution
        $blog->updateBlogContribution($blogContribution);

		$message	= JText::_('COM_EASYBLOG_DASHBOARD_ENTRIES_SAVED');

		// @task: 3rd party points integrations.
		if($isNew && $blog->published == POST_ID_PUBLISHED)
		{
			if( ($my->id != 0) && $config->get('main_jomsocial_userpoint') )
			{
				$path	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
				if( JFile::exists( $path ) )
				{
					require_once( $path );
					CUserPoints::assignPoint( 'com_easyblog.blog.add' , $blog->created_by );
				}
			}

			// AlphaUserPoint
			// since 1.2
			if( ($my->id != 0) && EasyBlogHelper::isAUPEnabled() )
			{
				AlphaUserPointsHelper::newpoints( 'plgaup_easyblog_add_blog', '', 'easyblog_add_blog_' . $blog->id, JText::sprintf('COM_EASYBLOG_AUP_NEW_BLOG_CREATED', EasyBlogRouter::_('index.php?option=com_easyblog&view=entry&id='.$blog->id) , $blog->title) );
			}
		}

		// @task: 3rd party activity integrations.
		if(($blog->published == POST_ID_PUBLISHED))
		{
			EasyBlogHelper::addJomSocialActivityBlog($blog, $isNew);
		}

		$blogId		= $blog->id;

		//meta post info
		$metaId		= $blog->getMetaId();

		$metapost	= array();
		$metapost['keywords']		= $draft->metakey;
		$metapost['description']	= $draft->metadesc;
		$metapost['content_id']		= $blog->id;
		$metapost['type']			= META_TYPE_POST;

		// @rule: Save meta tags for this entry.
		$meta		=& JTable::getInstance( 'Meta', 'Table' );
		$meta->load( $metaId );
		$meta->bind( $metapost );
		$meta->store();

		$author		=& JTable::getInstance( 'Profile', 'Table' );
		$author->load( $blog->created_by );

		// @task: Store trackbacks into the trackback table for tracking purposes.
		$trackbacks	= $draft->trackbacks;
		
		if( !empty( $acl->rules->add_trackback) && !empty( $trackbacks ) )
		{
			$rows	= explode( "\n" , $trackbacks);

			foreach( $rows as $row )
			{
				$trackback	= JTable::getInstance( 'TrackbackSent' , 'Table' );

				if( !$trackback->load( $row , true , $blog->id ) )
				{
					$trackback->post_id		= $blog->id;
					$trackback->url			= $row;
					$trackback->sent		= 0;
					$trackback->store();
				}
			}
		}

		// @task: Process additional stuffs if the blog is published
		if ( $blog->published == POST_ID_PUBLISHED )
		{
			$trackbackModel =& $this->getModel('TrackbackSent');

			// get lists of trackback URLs based on blog ID
			$trackbacks		= $trackbackModel->getSentTrackbacks( $blogId , true );

			require_once( EBLOG_CLASSES . DS . 'trackback.php' );
			require_once( EBLOG_HELPERS . DS . 'router.php' );

			if( $trackbacks )
			{
				foreach( $trackbacks as $trackback )
				{
					$tb		= new EasyBlogTrackBack( $author->getName() , $author->getName() , 'UTF-8' );
					$text	= empty( $blog->intro ) ? $blog->content : $blog->intro;
					$url	= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&view=entry&id=' . $blog->id , false , true );

					if( $tb->ping( $trackback->url , $url , $blog->title , $text ) )
					{
						$table		= JTable::getInstance( 'TrackbackSent' , 'Table' );
						$table->load( $trackback->id );
						$table->markSent();
					}
				}
			}
		}

		// @task: Save any tags associated with the blog entry.
		$postTagModel	=& $this->getModel( 'PostTag' );
		$tags           = explode(',', $draft->tags);
		$date			=& JFactory::getDate();

		// @task: Delete existing associated tags.
		$postTagModel->deletePostTag( $blog->id );

		if( !empty( $tags ) )
		{
			$tagModel	=& $this->getModel( 'Tags' );

			foreach( $tags as $tag )
			{
				if(!empty($tag))
				{
					$table	=& JTable::getInstance( 'Tag' , 'Table' );

					//@task: Only add tags if it doesn't exist.
					if( !$table->exists( $tag ) )
					{
						if($acl->rules->create_tag)
						{
							$tagInfo['created_by']	= $blog->created_by;
							$tagInfo['title'] 		= JString::trim($tag);
							$tagInfo['created']		= $date->toMySQL();

							$table->bind($tagInfo);

							$table->published	= 1;
							$table->status		= '';

							$table->store();

							if( $blog->created_by != 0 && $config->get('main_jomsocial_userpoint') )
							{
								$path	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
								if( JFile::exists( $path ) )
								{
									require_once( $path );
									CUserPoints::assignPoint( 'com_easyblog.tag.add' , $blog->created_by );
								}
							}

						}
					}
					else
					{
						$table->load( $tag , true );
					}

					//@task: Store in the post tag
					$postTagModel->add( $table->id , $blog->id , $date->toMySQL() );
				}
			}
		}

		// @task: check if the auto featured enabled.
		if( $config->get('main_autofeatured', 0) && EasyBlogHelper::isFeatured('blogger', $blog->created_by) )
		{
	        if(! EasyBlogHelper::isFeatured('post', $blog->id) )
	        {
	        	EasyBlogHelper::makeFeatured('post', $blog->id);
		    }
		}

		$autopost	= $draft->autopost;

		if( !empty( $autopost ) )
		{
			$allowed	= array( EBLOG_OAUTH_LINKEDIN , EBLOG_OAUTH_FACEBOOK , EBLOG_OAUTH_TWITTER );

			foreach( $autopost as $item )
			{
				if( in_array( $item , $allowed ) && $blog->published == POST_ID_PUBLISHED && $config->get( 'integrations_' . $item ) )
				{
					EasyBlogSocialShareHelper::share( $blog , constant( 'EBLOG_OAUTH_' . JString::strtoupper( $item ) ) );
				}
			}
		}

		if( $isNew && ($blog->published == POST_ID_PUBLISHED) )
		{
			// the sequece of the email data will be the same as the sequence in jtext::sprint params
			$emailData['blogTitle']		= $blog->title;
			$emailData['blogAuthor']	= $author->getName();
			$emailData['blogLink']		= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&view=entry&id='. $blog->id, false, true);
			$notify						=& EasyBlogHelper::getNotification();

			// send notification to admins
			if($config->get('notification_blogadmin'))
			{
				$notify->notifyAdmins( JText::_('COM_EASYBLOG_EMAIL_TITLE_NEW_BLOG_ADDED') , '' , 'email.blog.new.php' , $emailData );
			}

			if( $config->get( 'notification_allmembers' ) )
			{
                  EasyBlogSubscription::blogSendToAll( $blog, $emailData );
			}
			else
			{
			    // process all subscroptions on new blog post.
                  EasyBlogSubscription::processNewBlogNotification( $blog, $emailData, $blogContribution );
			}

			if( $config->get( 'main_pingomatic' ) )
			{
				if( !EasyBlogHelper::getHelper( 'Pingomatic' )->ping( $blog->title , EasyBlogHelper::getExternalLink('index.php?option=com_easyblog&view=entry&id=' . $blog->id, true) ) )
				{
					EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_SAVE_PINGOMATIC_ERROR') , 'error');
				}
			}

			$blog->isnew    = '0';
			$blog->store();
		}
		
		// @task: Cleanup any messages
		$postreject	= JTable::getInstance( 'PostReject' , 'Table' );
		$postreject->clear( $draft->id );
		
	    // now blog updated, we need to remove the draft
	    $draft->delete();

		EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_SAVE_SUCCESS')  , 'success');
		$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=pending', false) );
	}
	
	/*
	 * Responsible to reject a blog post
	 *
	 * @param	null
	 */	 
	function rejectBlog()
	{
		$mainframe  =& JFactory::getApplication();
		$redirect	= base64_decode( JRequest::getVar( 'redirect' , '' ) );
		$redirect	= empty( $redirect ) ? EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=pending' , false ) : EasyBlogRouter::_( $redirect , false );
		$my			= JFactory::getUser();
		$config     =& EasyBlogHelper::getConfig();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$ids  		= JRequest::getVar('ids', '');
		$ids		= explode( ',' , $ids );
		$message	= JRequest::getVar( 'message' , '' );
		
		if( empty( $ids ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error');
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}

		if( !EasyBlogHelper::isSiteAdmin() || empty( $acl->rules->manage_pending ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error');
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		JTable::addIncludePath( EBLOG_TABLES );

		foreach( $ids as $id )
		{
			$draft		=& JTable::getInstance( 'Draft', 'Table' );
			$draft->load( $id );

			if( $draft->pending_approval != 1 )
			{
				EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error');
				$mainframe->redirect( $redirect );
				$mainframe->close();
			}
			
			// If the draft is rejected, revert draft status and create a note for the rejected draft.
			$draft->set( 'pending_approval' , 0 );
			$draft->store();
			
			// Create the message
			$postreject				= JTable::getInstance( 'PostReject' , 'Table' );
			$postreject->draft_id	= $draft->id;
			$postreject->message	= $message;
			$postreject->created_by	= $my->id;
			$postreject->created	= JFactory::getDate()->toMySQL();
			$postreject->store();
		}

		EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_BLOG_REJECTED') , 'info');
		$mainframe->redirect( $redirect );
		$mainframe->close();
	}
	
	/**
	 * Delete a blog entry from the site given the id's.
	 **/
	public function deleteBlog()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$mainframe  =& JFactory::getApplication();
		$config     =& EasyBlogHelper::getConfig();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$my			= JFactory::getUser();
		$message	= '';
		$type		= '';
		
		$ids		= JRequest::getVar( 'blogId' , '' );
		$ids		= explode( ',' , $ids );
		$redirect	= JRequest::getVar( 'redirect' , '' );
		$redirect	= empty( $redirect ) ? 'index.php?option=com_easyblog' : base64_decode( $redirect );
		
		$redirect	= EasyBlogRouter::_( $redirect , false );
		
		if( empty( $ids ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_DELETE_NO_ID_ERROR' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}

		if( (empty($acl->rules->delete_entry) || $my->id == 0 ) && !EasyBlogHelper::isSiteAdmin() && empty($acl->rules->moderate_entry))
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NO_PERMISSION_TO_DELETE_BLOG' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		JTable::addIncludePath( EBLOG_TABLES );

		JPluginHelper::importPlugin( 'easyblog' );
		$dispatcher =& JDispatcher::getInstance();
		
		foreach( $ids as $id )
		{
			$blog	= JTable::getInstance( 'Blog' , 'Table' );
			$blog->load( $id );
			
			if( $blog->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() && empty($acl->rules->moderate_entry))
			{
				EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error');
				$mainframe->redirect( $redirect );
				$mainframe->close();
			}
			
			if( $blog->delete() )
			{
			    // Run some cleanup for autoarticle plugins.
			    $dispatcher->trigger('onAfterEasyBlogDelete', array(&$blog ));
			    
				// Delete all relations with this blog entry.
				$blog->deleteBlogTags();
				$blog->deleteMetas();
				$blog->deleteComments();
				
				// @task: Integrations with Jomsocial. Remove points necessarily.
				if( $config->get( 'main_jomsocial_userpoint' ) )
				{
				
					$path	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
					if( JFile::exists( $path ) )
					{
						require_once( $path );
						CUserPoints::assignPoint( 'com_easyblog.blog.remove' , $blog->created_by );
					}
				}
				
				// @since 1.2
				// AlphaUserPoints integrations. Remove points necessarily
				if ( EasyBlogHelper::isAUPEnabled() )
				{
					AlphaUserPointsHelper::newpoints( 'plgaup_easyblog_delete_blog', AlphaUserPointsHelper::getAnyUserReferreID( $blog->created_by ) , '', JText::sprintf('COM_EASYBLOG_AUP_BLOG_DELETED', $blog->title) );
				}
			}
			else
			{
				EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_DELETE_ERROR' ) , 'error' );
				$mainframe->redirect( $redirect );
				$mainframe->close();
			}
		}
		
		EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_DELETE_SUCCESS' , 'success' ) );
		$mainframe->redirect( $redirect );
		$mainframe->close();
	}
	
	function _saveDraft( $redirect, $pendingAppoval = false )
	{
		$mainframe		=& JFactory::getApplication();
		$config 		=& EasyBlogHelper::getConfig();
		$message		= '';
		$type			= 'message';
		$my				=& JFactory::getUser();
		$acl			= EasyBlogACLHelper::getRuleSet();
		$joomlaVersion	= EasyBlogHelper::getJoomlaVersion();
		
		if( $my->id == 0 )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_YOU_ARE_NOT_LOGIN') , 'error' );
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog' , false ) );
		}

		if( JRequest::getMethod() != 'POST' )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_SAVE_INVALID_METHOD') , 'error' );
			$mainframe->redirect( EasyBlogRouter::_( $redirect , false ) );
		}

		if( empty( $acl->rules->add_entry ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_CREATE_DRAFT') , 'warning');
			$mainframe->redirect( EasyBlogRouter::_( $redirect , false ) );
			return;
		}

		$params		= JRequest::get( 'post' );

		// Try to load this draft to see if it exists
		$draft	= JTable::getInstance( 'Draft' , 'Table' );
		$draft->load( $params[ 'draft_id' ] );

		if( isset( $params[ 'id' ] ) && !empty( $params[ 'id' ] ) )
		{
			$draft->entry_id	= $params[ 'id' ];
			unset( $params[ 'id' ] );
		}

		$content		= JRequest::getVar('write_content', '', 'post', 'string', JREQUEST_ALLOWRAW );
		$intro			= JRequest::getVar('intro', '', 'post', 'string', JREQUEST_ALLOWRAW );
		$params[ 'content' ]	= $content;
		$params[ 'intro' ] 		= $intro;

		$trackbacks	= JRequest::getVar( 'trackback' , '' , 'POST' );
		$params[ 'trackback' ]  = $trackbacks;
		$draft->bind( $params , true );

		if( isset( $params[ 'draft_id'] ) && !empty( $params[ 'draft_id' ] ) )
		{
			$draft->id	= $params[ 'draft_id' ];
		}

		if( $draft->id && $draft->created_by != $my->id )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_NOT_ALLOWED') , 'warning');
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard' , false ) );
			return;
		}
		
		if( $pendingAppoval )
		    $draft->pending_approval    = '1';

		if( $draft->store() )
		{
		    $message    = JText::_('COM_EASYBLOG_DASHBOARD_DRAFTS_SAVE_SUCCESS');
		
		    if( $pendingAppoval )
		    {
			    //send notification to admins.
				$author =& JTable::getInstance( 'Profile', 'Table' );
				$author->load( $draft->created_by );

				$emailData['blogTitle']		= $draft->title;
				$emailData['blogAuthor']	= $author->getName();
				$notify						=& EasyBlogHelper::getNotification();

				// send notification to admins
				$notify->notifyAdmins( JText::_('COM_EASYBLOG_EMAIL_TITLE_NEW_BLOG_PENDING_REVIEW') , '' , 'email.blog.pending.review.php' , $emailData );
		    
		        $message    = JText::_('COM_EASYBLOG_DASHBOARD_SAVE_BLOG_BUT_PENDING_FOR_APPROVAL');
		    }
		
			EasyBlogHelper::setMessageQueue( $message  , 'success');
			$mainframe->redirect( EasyBlogRouter::_( $redirect, false) );
			
		}
		else
		{
		    EasyBlogHelper::setMessageQueue( $draft->getError() , 'error');
			$mainframe->redirect( EasyBlogRouter::_( $redirect , false) );
		}
	}


	function savedraft()
	{
		$mainframe		=& JFactory::getApplication();
		$redirect   = 'index.php?option=com_easyblog&view=dashboard&layout=drafts';
		$this->_saveDraft( $redirect );
		return;
	}
	
	function savepending()
	{
		$mainframe		=& JFactory::getApplication();
		$redirect   = 'index.php?option=com_easyblog&view=dashboard&layout=entries';

		$this->_saveDraft( $redirect, true );
		return;
	}

	/*
	 * Saving a blog entry
	 *
	 * @param	null
	 * @return	null
	 */	 
	function save()
	{
		$mainframe	=& JFactory::getApplication();		
		$config 	=& EasyBlogHelper::getConfig();
		$message	= '';
		$type		= 'message';
		$my			=& JFactory::getUser();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$joomlaVersion = EasyBlogHelper::getJoomlaVersion();

		if( empty( $acl->rules->add_entry ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_CREATE_BLOG') , 'warning');
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard' , false ) );
			return;
		}		

		if( $my->id == 0 )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_YOU_ARE_NOT_LOGIN') , 'error' );
			$this->setRedirect( EasyBlogRouter::_( 'index.php?option=com_easyblog' , false ) );
		}
		
		if( JRequest::getMethod() != 'POST' )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_SAVE_INVALID_METHOD') , 'error' );
			$this->setRedirect( EasyBlogRouter::_( 'index.php?option=com_easyblog' , false ) );
		}
		
		JPluginHelper::importPlugin( 'easyblog' );
		$dispatcher =& JDispatcher::getInstance();			
		$blog		=& JTable::getInstance( 'blog', 'Table' );
		$post		= JRequest::get( 'post' );
		$id			= JRequest::getInt( 'id' );

		$isNew		= ( $blog->load( $id ) ) ? false : true;

		// There seems to be a bug in Joomla 1.6 where the load always return true
		// when invalid id is submitted
		if( $blog->id == 0 )
		{
			$isNew	= true;
		}
		
		if(! $isNew)
		{
		    // if this is blog edit, then we should see the column isnew to determine
		    // whether we should send any notification
		    $isNew  = $blog->isnew;
		}
		
		$under_approval = false;
		if( isset($post['under_approval']) )
		{
		    $under_approval = true;
		}

		// we do not proccess this on draft
		if ( $post['published'] != POST_ID_DRAFT ) 
		{
			$txOffset		= EasyBlogDateHelper::getOffSet();
			$today   		=& JFactory::getDate();
			
			if($post['published'] == POST_ID_PUBLISHED)
			{
				// we check the publishing date here
				// if user set the future date then we will automatically change
				// the status to Schedule

				$publishing 	=& JFactory::getDate( !isset($post['publish_up']) ? '' : $post[ 'publish_up' ] , $txOffset);

				if ( $publishing->toUnix() > $today->toUnix() )
				{
					$post['published'] = POST_ID_SCHEDULED;
				}
			}
		}

		$post[ 'publish_down' ] = JRequest::getVar( 'publish_down' , '0000-00-00 00:00:00' );

		// @task: Password encryption for blog entry
		if( isset($post['blogpassword']) && !empty($post['blogpassword']) && ($isNew || !EasyBlogHelper::isFeatured( 'post' , $blog->id )) )
		{
			$post['blogpassword'] = $post['blogpassword'];
		}
		else
		{
			$post['blogpassword']='';
		}
			
		// @task: Map the request.
		$blog->bind( $post , true );
		
		
		// @task: For edited blogs, ensure that they have permissions to edit it.
		if( !$isNew && $blog->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() && empty($acl->rules->moderate_entry) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' )  , 'error');
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard' , false ) );
			return;
		}
		

		if( empty($blog->title) || $blog->title == JText::_( 'COM_EASYBLOG_DASHBOARD_WRITE_DEFAULT_TITLE' ) )
		{
		    $post['write_content']  = JRequest::getVar('write_content', '', 'post', 'string', JREQUEST_ALLOWRAW );
			$post['intro']	= JRequest::getVar('intro', '', 'post', 'string', JREQUEST_ALLOWRAW );
		    EasyBlogHelper::storeSession( $post , 'tmpBlogData');
		    EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_SAVE_EMPTY_TITLE_ERROR') , 'error');
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=write' , false) );
		}
		
		if( empty($blog->content) && empty($blog->intro) )
		{
		    $post['write_content']  = JRequest::getVar('write_content', '', 'post', 'string', JREQUEST_ALLOWRAW );
			$post['intro']	= JRequest::getVar('intro', '', 'post', 'string', JREQUEST_ALLOWRAW );
		    EasyBlogHelper::storeSession( $post , 'tmpBlogData');
		    EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_SAVE_CONTENT_ERROR') , 'error');
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=write' , false) );
		}
		
		
		/**
		 * check here if user do not have the 'Publish Entry' acl, send this post for pending approval.
		 */
		if( empty($acl->rules->publish_entry) )
		{
			$this->savepending();
			return;
		}
		

		//check if user have permission to enable privacy.
		$blog->private	= empty( $acl->rules->enable_privacy ) ? 0 : $blog->private;
			
		//check if user have permission to contribute the blog post to eblog frontpage
		$blog->frontpage 	= (empty($acl->rules->contribute_frontpage)) ? '0' : $blog->frontpage;
		$blog->isnew 		= ($isNew && ($blog->published != 1)) ? '1' : '0';

		//now we need to check the blog contribution
		$blog->issitewide	= isset( $post[ 'blog_contribute' ] ) && $post[ 'blog_contribute' ] != 0 ? false : true;
		$blogContribution   = array();
		$issitewide 		= '1';

		if( isset( $post['blog_contribute']) && $post[ 'blog_contribute' ] == '0' )
		{
			$blog->issitewide	= true;
		}
		else
		{
			$blog->issitewide	= false;
			$blogContribution[]	= $post[ 'blog_contribute' ];
		}

		//onBeforeEasyBlogSave trigger start
		$blog->introtext	= '';
		$blog->text			= '';
		$dispatcher->trigger( 'onBeforeEasyBlogSave' , array( &$blog , $isNew ) );			
		//onBeforeEasyBlogSave trigger end

		//onBeforeContentSave trigger start
		$blog->introtext	= $blog->intro;
		$blog->text			= $blog->content;

		if($joomlaVersion >= '1.6')
		{
			$dispatcher->trigger('onContentBeforeSave', array('easyblog.blog', &$blog, $isNew));
		} 
		else
		{
			$dispatcher->trigger('onBeforeContentSave', array(&$blog, $isNew));
		}
			
		$blog->intro		= $blog->introtext;
		$blog->content		= $blog->text;
		unset($blog->introtext);
		unset($blog->text);
		//onBeforeContentSave trigger end

		// @task: When a new post is saved, we need to clear the drafts first.
		if( isset( $post[ 'draft_id' ] ) && !empty( $post[ 'draft_id' ] ) )
		{
			$draft		= JTable::getInstance( 'Draft' , 'Table' );
			$draft->load( $post[ 'draft_id' ] );
			
			// @rule: Only delete the draft when the owner really owns the draft.
			if( $draft->created_by == $my->id || EasyBlogHelper::isSiteAdmin() || $under_approval )
			{
				if( $under_approval )
				{
					// @task: Cleanup any messages
					$postreject	= JTable::getInstance( 'PostReject' , 'Table' );
					$postreject->clear( $draft->id );
				}
				
				$draft->delete();
			}
		}

		if (!$blog->store()) 
		{
		    EasyBlogHelper::setMessageQueue( $blog->getError() , 'error');
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=write' , false) );
		}

		//onAfterEasyBlogSave trigger start
		$blog->introtext	= "";
		$blog->text			= "";
		$dispatcher->trigger('onAfterEasyBlogSave', array(&$blog, $isNew));			
		//onAfterEasyBlogSave trigger end

		//onAfterContentSave trigger start
		$blog->introtext	= $blog->intro;
		$blog->text			= $blog->content;
		
		if($joomlaVersion >= '1.6')
		{
			$dispatcher->trigger('onContentAfterSave', array('easyblog.blog', &$blog, $isNew));
		} 
		else
		{
			$dispatcher->trigger('onAfterContentSave', array(&$blog, $isNew));
		}
		
		$blog->excerpt		= $blog->introtext;
		$blog->content		= $blog->text;
		unset($blog->introtext);
		unset($blog->text);
		//onAfterContentSave trigger end
			
		// this variable will be use when sending notification. This is bcos
		// the currently login use might be the admin and editing other blogger post.
	    $authorId   = $blog->created_by;

        //now we update the blog contribution
        $blog->updateBlogContribution($blogContribution);

		$message	= JText::_('COM_EASYBLOG_DASHBOARD_ENTRIES_SAVED');
		
		// @task: 3rd party points integrations.
		if($isNew && $blog->published == POST_ID_PUBLISHED)
		{
			if( ($my->id != 0) && ( $blog->created_by == $my->id) && $config->get('main_jomsocial_userpoint') )
			{
				$path	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
				if( JFile::exists( $path ) )
				{
					require_once( $path );
					CUserPoints::assignPoint( 'com_easyblog.blog.add' , $blog->created_by );
				}
			}
			
			// AlphaUserPoints
			// since 1.2
			if( ($my->id != 0) && ( $blog->created_by == $my->id) && EasyBlogHelper::isAUPEnabled() )
			{
				AlphaUserPointsHelper::newpoints( 'plgaup_easyblog_add_blog', '', 'easyblog_add_blog_' . $blog->id, JText::sprintf('COM_EASYBLOG_AUP_NEW_BLOG_CREATED', EasyBlogRouter::_('index.php?option=com_easyblog&view=entry&id='.$blog->id) , $blog->title) );
			}
		}
			
		// @task: 3rd party activity integrations.
		if(($blog->published == POST_ID_PUBLISHED) && ($my->id == $authorId) && (! $blog->ispending) )
		{
			EasyBlogHelper::addJomSocialActivityBlog($blog, $isNew);
		}

		$blogId		= $blog->id;

		//meta post info
		$metaId		= JRequest::getVar( 'metaid' , '' );
			
		$metapost	= array();
		$metapost['keywords']		= JRequest::getVar('keywords', '');
		$metapost['description']	= JRequest::getVar('description', '');
		$metapost['content_id']		= $blog->id;
		$metapost['type']			= META_TYPE_POST;
			
		// @rule: Save meta tags for this entry.
		$meta		=& JTable::getInstance( 'Meta', 'Table' );
		$meta->load( $metaId );
		$meta->bind( $metapost );
		$meta->store();

		$author		=& JTable::getInstance( 'Profile', 'Table' );
		$author->load( $blog->created_by );
		
		// @task: Store trackbacks into the trackback table for tracking purposes.
		$trackbacks	= JRequest::getVar( 'trackback' , '' , 'POST' );
		if( !empty( $acl->rules->add_trackback) && !empty( $trackbacks ) )
		{
			$rows	= explode( "\n" , $trackbacks);
			
			foreach( $rows as $row )
			{
				$trackback	= JTable::getInstance( 'TrackbackSent' , 'Table' );
				
				if( !$trackback->load( $row , true , $blog->id ) )
				{
					$trackback->post_id		= $blog->id;
					$trackback->url			= $row;
					$trackback->sent		= 0;
					$trackback->store();
				}
			}
		}
		
		// @task: Process additional stuffs if the blog is published
		if ( $blog->published == POST_ID_PUBLISHED )
		{ 
			$trackbackModel =& $this->getModel('TrackbackSent');

			// get lists of trackback URLs based on blog ID
			$trackbacks		= $trackbackModel->getSentTrackbacks( $blogId , true );

			require_once( EBLOG_CLASSES . DS . 'trackback.php' );
			require_once( EBLOG_HELPERS . DS . 'router.php' );
			
			if( $trackbacks )
			{
				foreach( $trackbacks as $trackback )
				{
					$tb		= new EasyBlogTrackBack( $author->getName() , $author->getName() , 'UTF-8' );
					$text	= empty( $blog->intro ) ? $blog->content : $blog->intro;
					$url	= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&view=entry&id=' . $blog->id , false , true );
					
					if( $tb->ping( $trackback->url , $url , $blog->title , $text ) )
					{
						$table		= JTable::getInstance( 'TrackbackSent' , 'Table' );
						$table->load( $trackback->id );
						$table->markSent();
					}
				}
			}
		}

		// @task: Save any tags associated with the blog entry.
		$postTagModel	=& $this->getModel( 'PostTag' );
		$tags			= JRequest::getVar( 'tags' , '' , 'POST' );
		$date			=& JFactory::getDate();

		// @task: Delete existing associated tags.
		$postTagModel->deletePostTag( $blog->id );

		if( !empty( $tags ) )
		{
			$tagModel	=& $this->getModel( 'Tags' );
			
			foreach( $tags as $tag )
			{
				if(!empty($tag))
				{
					$table	=& JTable::getInstance( 'Tag' , 'Table' );
					
					//@task: Only add tags if it doesn't exist.
					if( !$table->exists( $tag ) )
					{
						if($acl->rules->create_tag)
						{
							$tagInfo['created_by']	= $my->id;
							$tagInfo['title'] 		= JString::trim($tag);
							$tagInfo['created']		= $date->toMySQL();
							
							$table->bind($tagInfo);
							
							$table->published	= 1;
							$table->status		= '';
							
							$table->store();
							
							if( $my->id != 0 && $config->get('main_jomsocial_userpoint') )
							{
								$path	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
								if( JFile::exists( $path ) )
								{
									require_once( $path );
									CUserPoints::assignPoint( 'com_easyblog.tag.add' , $my->id );
								}
							}
							
						}
					}
					else
					{
						$table->load( $tag , true );
					}
					
					//@task: Store in the post tag
					$postTagModel->add( $table->id , $blog->id , $date->toMySQL() );
				}
			}
		}
			
		// @task: check if the auto featured enabled.
		if( $config->get('main_autofeatured', 0) && EasyBlogHelper::isFeatured('blogger', $blog->created_by) )
		{
	        if(! EasyBlogHelper::isFeatured('post', $blog->id) )
	        {
	        	EasyBlogHelper::makeFeatured('post', $blog->id);
		    }
		}

		$autopost	= JRequest::getVar( 'socialshare' , '' );
		
		if( !empty( $autopost ) )
		{
			$allowed	= array( EBLOG_OAUTH_LINKEDIN , EBLOG_OAUTH_FACEBOOK , EBLOG_OAUTH_TWITTER );

			foreach( $autopost as $item )
			{
				if( in_array( $item , $allowed ) && $blog->published == POST_ID_PUBLISHED && $config->get( 'integrations_' . $item ) )
				{
					EasyBlogSocialShareHelper::share( $blog , constant( 'EBLOG_OAUTH_' . JString::strtoupper( $item ) ) );
				}
			}
		}

		if( $isNew && ($blog->published == POST_ID_PUBLISHED) )
		{
			// the sequece of the email data will be the same as the sequence in jtext::sprint params
			$emailData['blogTitle']		= $blog->title;
			$emailData['blogAuthor']	= $author->getName();
			$emailData['blogLink']		= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&view=entry&id='. $blog->id, false, true);
			$notify						=& EasyBlogHelper::getNotification();

			// send notification to admins
			if($config->get('notification_blogadmin'))
			{
				$notify->notifyAdmins( JText::_('COM_EASYBLOG_EMAIL_TITLE_NEW_BLOG_ADDED') , '' , 'email.blog.new.php' , $emailData );
			}
			
			if( $config->get( 'notification_allmembers' ) )
			{
                  EasyBlogSubscription::blogSendToAll( $blog, $emailData );
			}
			else
			{
			    // process all subscroptions on new blog post.
                  EasyBlogSubscription::processNewBlogNotification( $blog, $emailData, $blogContribution );
			}
			
			if( $config->get( 'main_pingomatic' ) )
			{
				if( !EasyBlogHelper::getHelper( 'Pingomatic' )->ping( $blog->title , EasyBlogHelper::getExternalLink('index.php?option=com_easyblog&view=entry&id=' . $blog->id, true) ) )
				{
					EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_SAVE_PINGOMATIC_ERROR') , 'error');
				}
			}

			$blog->isnew    = '0';
			$blog->store();
		}

		EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_SAVE_SUCCESS')  , 'success');
		$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=entries', false) );
	}

	function saveAdsenseUserParams()
	{
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config     =& EasyBlogHelper::getConfig();
		
		$this->checkLogin();
		
		if( $config->get( 'integration_google_adsense_enable' ) )
		{
			if(! empty($acl->rules->add_adsense))
			{
				$mainframe	=& JFactory::getApplication();
				$my			=& JFactory::getUser();
				$post		= JRequest::get( 'post' );

				array_walk($post, array($this, '_trim') );

				$adsense =& JTable::getInstance( 'Adsense', 'Table' );
		    	$adsense->load($my->id);

		    	// Prevent Joomla from acting funny as on some site's it automatically adds the quote character at the end.
				$adsense->code 		= rtrim( $post['adsense_code'] , '"' );
				$adsense->display 	= $post['adsense_display'];
				$adsense->published = $post['adsense_published'];

				if(!$adsense->store())
				{
	                EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_ADSENSE_FAILED_TO_UPDATE_INFO') , 'error');
				}
			}
		}
	}	
	
	function _trim(&$text)
	{
		$text = JString::trim($text);		
	}


	/**
	 * validate the required data from form submit
	 * param - array - forms
	 *       - array - required keys + message	 	 
	 * return boolean	 
	 */ 	
	function _validateAppsFields($post, $requiredKeys)
	{
		$mainframe	=& JFactory::getApplication();
		$valid		= true;
		
		if(is_array($requiredKeys))
		{
			foreach($requiredKeys as $key => $val)
			{
				if(JString::strlen($post[$key]) == 0)
				{
					EasyBlogHelper::setMessageQueue( JText::_($val)  , 'warning');
					$valid	= false;
					break;
				}			
			}
		}
		else
		{
			$valid	= false;
			EasyBlogHelper::setMessageQueue( JText::_('MISSING REQUIRED KEY FOR VALIDATION') , 'error');
		}
		return $valid;		
	}

	function _upload( $profile, $type = 'profile' )
	{
	    $newAvatar	= $type == 'category' ? EasyBlogHelper::uploadCategoryAvatar( $profile ) : EasyBlogHelper::uploadAvatar( $profile );

		return $newAvatar;
	}
	
	function saveProfile()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$mainframe	=& JFactory::getApplication();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$post		= JRequest::get( 'post' );
		$config		= EasyBlogHelper::getConfig();
		$this->checkLogin();
		
		if( EasyBlogHelper::isSiteAdmin())
		{
			$post['description']	= JRequest::getVar( 'description' , '' , 'POST' , '' , JREQUEST_ALLOWRAW );
			$post['biography']		= JRequest::getVar( 'biography' , '' , 'POST' , '' , JREQUEST_ALLOWRAW );
		}
		array_walk($post, array($this, '_trim') );

		if( $config->get( 'main_dashboard_editaccount' ) )
		{
			if(! $this->_validateProfileFields($post))
			{
				$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=profile' , false ) );
				return;
			}
		}
		
		$my			=& JFactory::getUser();

		if( $config->get( 'main_joomlauserparams' ) )
		{
			$my->name	= $post['fullname'];

			$email		= $post[ 'email' ];
			$password	= $post[ 'password' ];
			$password2	= $post[ 'password2' ];

			if( JString::strlen( $password ) || JString::strlen( $password2 ) )
			{
				if( $password != $password2 )
				{
					EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_ACCOUNT_PASSWORD_ERROR')  , 'error' );
					$this->setRedirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=profile' , false ) );
					
					return false;
				}
			}
	
			// Store basic Joomla information
			$user		= JFactory::getUser();
			$data		= array( 'email' => $email , 'password' => $password , 'password2' => $password2 );
			$user->bind( $data );


			if (!$user->save())
			{
				EasyBlogHelper::setMessageQueue( $user->getError() , 'error' );
				$this->setRedirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=profile' , false ) );			
				return false;
			}
	
			$session =& JFactory::getSession();
			$session->set('user', $user);
	
			$table = JTable::getInstance( 'Session' , 'JTable');
			$table->load($session->getId());
			$table->username = $user->get('username');
			$table->store();
		}

		$post['permalink']  = $post['user_permalink'];
		unset( $post['user_permalink'] );

		$profile	=& JTable::getInstance( 'Profile', 'Table' );
		$profile->load( $my->id );
		$profile->bind( $post );

		if( $config->get('main_feedburner') && $config->get('main_feedburnerblogger') && !empty($acl->rules->allow_feedburner))
		{
			$feedburner	=& JTable::getInstance( 'Feedburner' , 'Table' );
			$feedburner->load( $my->id );
			$feedburner->url	= $post['feedburner_url'];

			$feedburner->store();
		}
		
		JTable::addIncludePath( EBLOG_TABLES );
		if(! empty($acl->rules->update_twitter))
		{
			$mainframe	=& JFactory::getApplication();

			$twitter	= JTable::getInstance( 'Oauth' , 'Table' );
			$twitter->loadByUser( $my->id , EBLOG_OAUTH_TWITTER );

			$twitter->auto		= JRequest::getVar( 'integrations_twitter_auto' );
			$twitter->message	= JRequest::getVar( 'integrations_twitter_message' );
		
			if( !$twitter->store() )
			{
				EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_INTEGRATIONS_TWITTER_ERROR') , 'error');
			}
		}

		// Map linkedin items
		if(!empty($acl->rules->update_linkedin))
		{
			$mainframe	=& JFactory::getApplication();

			$linkedin	= JTable::getInstance( 'Oauth' , 'Table' );
			$linkedin->loadByUser( $my->id , EBLOG_OAUTH_LINKEDIN );

			$linkedin->auto		= JRequest::getVar( 'integrations_linkedin_auto' );
			$linkedin->message	= JRequest::getVar( 'integrations_linkedin_message' );
			$linkedin->private	= JRequest::getVar( 'integrations_linkedin_private' );
		
			if( !$linkedin->store() )
			{
				EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_INTEGRATIONS_LINKEDIN_ERROR') , 'error');
			}
		}

		if(!empty($acl->rules->update_facebook))
		{
			$mainframe	=& JFactory::getApplication();

			$facebook	= JTable::getInstance( 'Oauth' , 'Table' );
			$facebook->loadByUser( $my->id , EBLOG_OAUTH_FACEBOOK );

			$facebook->auto		= JRequest::getVar( 'integrations_facebook_auto' );
			$facebook->message	= '';
		
			if( !$facebook->store() )
			{
				EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_INTEGRATIONS_FACEBOOK_FAILED_UPDATE_INFO_ERROR') , 'error');
			}
		}
		
		$this->saveAdsenseUserParams();
		
		
		//save avatar
		if(! empty($acl->rules->upload_avatar))
		{
			$file 				= JRequest::getVar( 'Filedata', '', 'files', 'array' );
			if(! empty($file['name']))
			{
				$newAvatar			= $this->_upload( $profile );
				$profile->avatar    = $newAvatar;
				
				// AlphaUserPoints
				// since 1.2				
				if ( EasyBlogHelper::isAUPEnabled() )
				{
					AlphaUserPointsHelper::newpoints( 'plgaup_easyblog_upload_avatar', '', 'easyblog_upload_avatar_' . $my->id, JText::_('COM_EASYBLOG_AUP_UPLOADED_AVATAR') );
				}
			}
		}
		
		
		//save meta
		if(! empty($acl->rules->add_entry))
		{
			//meta post info
			$metaId     = JRequest::getInt('metaid', 0);
			$metapost	= array();
			
			$metapost['keywords']		= JRequest::getVar('metakeywords', '');
			$metapost['description']	= JRequest::getVar('metadescription', '');
			$metapost['content_id']		= $my->id;
			$metapost['type']			= META_TYPE_BLOGGER;

			$meta		=& JTable::getInstance( 'Meta', 'Table' );
			$meta->load($metaId);
			$meta->bind($metapost);
			$meta->store();
		}
		
		//save params
		$userparams	= new JParameter('');
		$userparams->set( 'theme', $post['theme'] );
		$profile->params = $userparams->toString();
		
		if( EasyBlogHelper::getJoomlaVersion() >= '1.6' ) 
		{
			//replacing thr group name with group id so it is save correctly into the Joomla group table.
			if(!empty($my->groups))
			{
				foreach($my->groups as $groupid=>$groupname)
				{
					$my->groups[$groupid] = $groupid;
				}
			}
		}

		if( $profile->store() && $my->save(true) )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_PROFILE_UPDATE_SUCCESS')  , 'info');
		}
		else
		{
		    EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_PROFILE_UPDATE_FAILED')  , 'error');
		}

		$this->setRedirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=profile' , false ) );
	}
	
	function _validateProfileFields($post)
	{
		$mainframe	= JFactory::getApplication();
		$valid		= true;
		
		$message    = '<ul>';

		if(JString::strlen($post['fullname']) == 0)
		{
			$message    .= '<li>' . JText::_('COM_EASYBLOG_DASHBOARD_ACCOUNT_REALNAME_EMPTY') . '</li>';
			$valid	= false;
		}
		
		if(JString::strlen($post['nickname']) == 0)
		{
			$message    .= '<li>' . JText::_('COM_EASYBLOG_DASHBOARD_ACCOUNT_NICKNAME_EMPTY') . '</li>';
			$valid	= false;
		}
		
		$message    .= '<ul>';
		
		EasyBlogHelper::setMessageQueue( $message , 'warning');
		
		return $valid;
	}
	
	public function checkLogin()
	{
		$mainframe	= JFactory::getApplication();
		
		if(! EasyBlogHelper::isLoggedIn())
		{
			$uri		= JFactory::getURI();
			$return		= $uri->toString();

			$url  = 'index.php?option=com_user&view=login';
			$url .= '&return='.base64_encode($return);
			$mainframe->redirect( EasyBlogRouter::_( $url , false ) , JText::_('COM_EASYBLOG_YOU_MUST_LOGIN_FIRST') );
		}
	}
	
	/*
	 * Adds new category
	 * @param	null
	 * @return	null
	 */	 	 	 	
	function addCategory()
	{
		$mainframe	=& JFactory::getApplication();
		$my         =& JFactory::getUser();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config     =& EasyBlogHelper::getConfig();
		
		$this->checkLogin();
		
		if(empty($acl->rules->create_category))
		{
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=categories' , false), JText::_('COM_EASYBLOG_NO_PERMISSION_TO_CREATE_CATEGORY') );
			$mainframe->close();
		}

		$catName = JRequest::getVar( 'category', '' );

		if(empty($catName))
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_CATEGORIES_EMPTY_CATEGORY_TITLE_ERROR') , 'error');
			$mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=categories' , false) );
			$mainframe->close();
		}
		
	    //check whether the category already created.
	    $model  =& $this->getModel('Category');
	    
	    if($model->isExist($catName))
	    {
	        EasyBlogHelper::setMessageQueue(JText::sprintf('COM_EASYBLOG_DASHBOARD_CATEGORIES_ALREADY_EXISTS_ERROR', $catName), 'error');
	        $mainframe->redirect( EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=categories' , false) );
	        $mainframe->close();
	    }
	    
	    $post['title'] 		= $catName;
	    $post['created_by'] = $my->id;
	    $post['parent_id'] 	= JRequest::getInt( 'parent_id', '0' );
	    $post['private'] 	= JRequest::getInt( 'private', '0' );
	    
	    $category	=& JTable::getInstance( 'ECategory', 'Table' );
        $category->bind($post);
        $category->published    = 1;
        
        //save the cat 1st so that the id get updated
        $category->store();
        
        // @since 1.2
		// AlphaUserPoints
		if ( $my->id != 0 && EasyBlogHelper::isAUPEnabled() )
		{
			AlphaUserPointsHelper::newpoints( 'plgaup_easyblog_add_category', '', 'easyblog_add_category_' . $category->id, JText::sprintf('COM_EASYBLOG_AUP_NEW_CATEGORY_CREATED', $catName) );
		}

		if( $my->id != 0 && $config->get('main_jomsocial_userpoint') )
		{
			$path	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
			if( JFile::exists( $path ) )
			{
				require_once( $path );
				CUserPoints::assignPoint( 'com_easyblog.category.add' , $my->id );
			}
		}
		        
		$file = JRequest::getVar( 'Filedata', '', 'files', 'array' );
		
		if(! empty($file['name']))
		{
			$newAvatar			= $this->_upload( $category, 'category' );
			$category->avatar   = $newAvatar;
			
			//now update the avatar.
			$category->store();
		}
	
	    EasyBlogHelper::setMessageQueue( JText::sprintf('COM_EASYBLOG_DASHBOARD_CATEGORIES_ADDED_SUCCESSFULLY' , $catName ) , 'success' );
	    $mainframe->redirect( EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=categories', false) );
	    $mainframe->close();
	}
	
	/*
	 * Responsible to store an edited category.
	 * @param	null
	 * @return	null
	 */	 
	function saveCategory()
	{
		$id			= JRequest::getVar( 'id' , '' );
		$acl		= EasyBlogACLHelper::getRuleSet();
		$my			= JFactory::getUser();
		$redirect	= EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=categories' , false );
		$mainframe	= JFactory::getApplication();
		
		// @rule: Sanity checks
		if( empty( $id ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_CATEGORIES_ID_IS_EMPTY_ERROR' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		// @rule: Check if the user is really allowed to create category.
		if( !$acl->rules->create_category)
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		// @rule: Check if the user is really allowed to edit this category
		$category	=& JTable::getInstance( 'ECategory' , 'Table' );
        $category->load( $id );

		if( $category->id && $category->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		$post		= JRequest::get( 'POST' );
		$category->bind( $post );

		$model		=& $this->getModel('Category');
		
		if( $model->isExist( $category->title , $category->id ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_CATEGORIES_ALREADY_EXISTS_ERROR' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}

		$avatar	= JRequest::getVar( 'Filedata', '', 'files', 'array' );

		if( isset( $avatar[ 'name' ] ) && !empty( $avatar['name'] ) )
		{
			$category->avatar   = EasyBlogHelper::uploadCategoryAvatar( $category );
		}
		$category->store();
		
		EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_CATEGORIES_UPDATED_SUCCESSFULLY' ) , 'success' );
		$mainframe->redirect( $redirect );
		$mainframe->close();        
	}
	
	function addTag()
	{
		$mainframe	=& JFactory::getApplication();
		$my         =& JFactory::getUser();
		$config     =& EasyBlogHelper::getConfig();
		
		$acl		= EasyBlogACLHelper::getRuleSet();
		
		$this->checkLogin();
		
		if( empty( $acl->rules->create_tag ) )
		{
			$url  = 'index.php?option=com_easyblog&view=dashboard&layout=tags';
			$mainframe->redirect(EasyBlogRouter::_($url, false), JText::_('COM_EASYBLOG_NO_PERMISSION_TO_CREATE_TAG') );
		}

		$tagName		= JRequest::getVar( 'tag', '' );

		if(empty($tagName))
		{
			EasyBlogHelper::setMessageQueue(JText::_('COM_EASYBLOG_DASHBOARD_TAG_INVALID'), 'error');
			$url  = 'index.php?option=com_easyblog&view=dashboard&layout=tags';
			$mainframe->redirect(EasyBlogRouter::_($url, false));
			return;
		}
		
		$arrTag = explode( ',', $tagName );
		
		$count  	= 0;
		$tagExists  = array();
		$tagAdded   = array();
		foreach( $arrTag as $item )
		{
		    if( empty( $item ) )
		    {
		        continue;
		    }
		    
			$table	=& JTable::getInstance( 'Tag' , 'Table' );
			//@task: Only add tags if it doesn't exist.
			if( !$table->exists( $item ) )
			{
				$post['title'] 		= JString::trim( $item );
				$post['created_by'] = $my->id;

				$table->bind($post);
				$table->published	= 1;

				$table->store();
				
				$tagAdded[] = $item;
    			$count++;

				if( $my->id != 0 && $config->get('main_jomsocial_userpoint') )
				{
					$jsUserPoint	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
					if( JFile::exists( $jsUserPoint ) )
					{
						require_once( $jsUserPoint );
						CUserPoints::assignPoint( 'com_easyblog.tag.add' , $my->id );
					}
				}

				// AlphaUserPoints
				// since 1.2
				if ( $my->id != 0 && EasyBlogHelper::isAUPEnabled() )
				{
					AlphaUserPointsHelper::newpoints( 'plgaup_easyblog_add_tag', '', 'easyblog_add_tag_' . $tag->id, JText::sprintf('COM_EASYBLOG_AUP_TAG_ADDED', $table->title) );
				}
			}
			else
			{
			    $tagExists[]    = $item;
			}
		}
		
		if( $count > 0 )
		{
		    $tagName    = implode( ', ', $tagAdded);
		    
	        EasyBlogHelper::setMessageQueue(JText::sprintf('COM_EASYBLOG_DASHBOARD_TAG_NAME_ADDED', $tagName), 'info');
		    $mainframe->redirect(EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=tags', false));
		    
		}
		else if( count( $tagExists ) > 0 )
		{
		    $tagName    = implode( ', ', $tagExists);
		    EasyBlogHelper::setMessageQueue(JText::sprintf('COM_EASYBLOG_DASHBOARD_TAG_NAME_ALREADY_EXISTS', $tagName), 'error');
	        $mainframe->redirect(EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=tags', false));
	        return;
		}
		else
		{
			EasyBlogHelper::setMessageQueue(JText::_('COM_EASYBLOG_DASHBOARD_TAG_INVALID'), 'error');
			$mainframe->redirect(EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=tags', false));
			return;
		}
	}
	
	/*
	 * List down bloggers from the site for the admin to change authors.
	 *
	 * @param	null
	 * @return	null
	 */	 
	function listBloggers()
	{
		// Anyone with moderate_entry acl is also allowed to change author.
		$acl		= EasyBlogACLHelper::getRuleSet();
		if( !EasyBlogHelper::isSiteAdmin() && !$acl->rules->moderate_entry )
		{
			echo JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			return;
		}
		
		$model 		=& $this->getModel( 'Users' );
		$rows		= $model->getUsers();
		$users		= array();
		
		JTable::addIncludePath( EBLOG_TABLES );
		foreach( $rows as $row )
		{
			$user		=& JTable::getInstance( 'Profile' , 'Table' );
			$user->load( $row->id );
			$users[]	= $user;
		}
		
		$pagination = $model->getPagination();
		
		$orderDir	= JRequest::getVar('filter_order_Dir', '', 'REQUEST');
		switch($orderDir)
		{
			case 'asc':
				$orderDir = 'desc';
				break;
			case 'desc':
			default:
				$orderDir = 'asc';
		}
		
		$order			= JRequest::getVar('filter_order', 'name', 'REQUEST');
		$search			= JRequest::getVar('search', '', 'REQUEST');
		$filter_state	= JRequest::getVar('filter_state', 'P', 'REQUEST');
		
		$tpl = new CodeThemes('dashboard');
		$tpl->set( 'users' 			, $users );
		$tpl->set( 'pagination'		, $pagination );
		$tpl->set( 'orderDir'		, $orderDir );
		$tpl->set( 'order'			, $order );
		$tpl->set( 'search'			, $search );
		$tpl->set( 'filter_state'	, $filter_state );
		
		echo $tpl->fetch( 'dashboard.users.php' );
		return;
	}
	
	function teamApproval()
	{
		$mainframe	=& JFactory::getApplication();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config 	=& EasyBlogHelper::getConfig();
		$document	=& JFactory::getDocument();
		$my			=& JFactory::getUser();
	
		if(! EasyBlogHelper::isLoggedIn())
		{
			$uri		= JFactory::getURI();
			$return		= $uri->toString();

			$url  = 'index.php?option=com_user&view=login';
			$url .= '&return='.base64_encode($return);
			$mainframe->redirect(EasyBlogRouter::_($url, false), JText::_('COM_EASYBLOG_YOU_MUST_LOGIN_FIRST') );
		}
		
		$teamId 	= JRequest::getInt('team', 0);
		$approval	= JRequest::getInt('approve');
		$requestId	= JRequest::getInt('id', 0);
		
		//check if the current user have the right to approve this team request or not.
		$teamModel 		=& $this->getModel( 'TeamBlogs' );
		
		if(! EasyBlogHelper::isSiteAdmin())
		{
			if(! $teamModel->checkIsTeamAdmin($my->id, $teamId))
			{
				EasyBlogHelper::showAccessDenied();
			}
		}
		
		$ok = true;
	    $teamRequest    =& JTable::getInstance( 'TeamBlogRequest','Table' );
	    $teamRequest->load($requestId);
		
		if($approval)
		{
		    $teamUsers    =& JTable::getInstance( 'TeamBlogUsers','Table' );
		    
		    $teamUsers->user_id    = $teamRequest->user_id;
		    $teamUsers->team_id    = $teamRequest->team_id;
		    
		    if($teamUsers->store())
		    {
		        EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_TEAMBLOG_APPROVAL_APPROVED')  , 'info');
		    }
		    else
		    {
		        $ok = false;
		        EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_TEAMBLOG_APPROVAL_FAILED')  , 'error');
			}
		}
		else
		{
		    EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_TEAMBLOG_APPROVAL_REJECTED')  , 'info');
		}
		
		if($ok)
		{
			$teamRequest->ispending = 0;
			$teamRequest->store();
			
			$teamBlog =& JTable::getInstance( 'TeamBlog','Table' );
			$teamBlog->load($teamRequest->team_id);
			
			//now we send notification to requestor
			$requestor  =& JFactory::getUser($teamRequest->user_id);
			$template   = ($approval) ? 'email.teamblog.request.approved.php' : 'email.teamblog.request.rejected.php';
			$toNotifyEmails = $requestor->email;
			
			$notify	=& EasyBlogHelper::getNotification();
			$emailData  = array();
			$emailData['team']  	= $teamBlog->title;
			$notify->sendEmails($toNotifyEmails, JText::_('COM_EASYBLOG_TEAMBLOG_JOIN_REQUEST'), '', $template, $emailData);
		}
		
		$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=teamblogs', false) );
	}

	/*
	 * @since 2.0
	 * Responsible to update an existing comment
	 * 	 
	 * @param	null
	 * @return	null
	 */	 
	public function updateComment()
	{
		$mainframe	=& JFactory::getApplication();
		$my			=& JFactory::getUser();
	    $acl		= EasyBlogACLHelper::getRuleSet();
	    $redirect	= EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=comments' , false );
	    
		if( empty($acl->rules->manage_comment) || $my->id == 0 )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_UPDATE_COMMENT') , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		$id			= JRequest::getInt( 'id' );
		$post		= JRequest::get( 'POST' );
		array_walk( $post, array( $this, '_trim') );

		//add here so that other component with the same comment.php jtable file will not get reference.
		JTable::addIncludePath( EBLOG_TABLES );
		$comment =& JTable::getInstance( 'Comment', 'Table' );
		$comment->bindPost( $post );

		$blog		= JTable::getInstance( 'Blog' , 'Table' );
		$blog->load( $comment->post_id );

		// @rule: Test if the current browser is allowed to do this or not.
		if( $blog->created_by != $my->id && !EasyBloghelper::isSiteAdmin() )
		{
			echo JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			exit;
		}
		
		if( !$comment->validate( 'title' ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_COMMENT_TITLE_IS_EMPTY') , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();	
		}

		if( !$comment->validate( 'name' ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_COMMENT_NAME_IS_EMPTY') , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();	
		}
		
		if( !$comment->validate( 'email' ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_COMMENT_EMAIL_IS_EMPTY') , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();	
		}

		if( !$comment->validate( 'comment' ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_COMMENT_IS_EMPTY') , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();	
		}	
		
		$comment->modified	= JFactory::getDate()->toMySQL();
		
		if( !$comment->store() )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_COMMENT_FAILED_TO_SAVE') , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_DASHBOARD_BOMMENTS_COMMENT_UPDATED_SUCCESS') , 'success' );
		$mainframe->redirect( $redirect );
		$mainframe->close();
	}

	/*
	 * @since 2.0
	 * Responsible to delete drafts
	 * 	 
	 * @param	null
	 * @return	null
	 */	
	public function deleteAllDrafts()
	{		
		$mainframe	= JFactory::getApplication();
		$my			= JFactory::getUser();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$redirect	= EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=drafts' , false );
		
		if( (empty($acl->rules->delete_entry) || $my->id == 0 ) && !EasyBlogHelper::isSiteAdmin() )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NO_PERMISSION_TO_DELETE_DRAFTS' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		$model		= $this->getModel( 'Drafts' );
		
		if( !$model->discard( $my->id ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_DRAFTS_DISCARDED_ERROR' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}

		EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_DRAFTS_DISCARDED_SUCCESSFULLY' ) , 'info');
		$mainframe->redirect( $redirect );
		$mainframe->close();
	}
	
	/*
	 * @since 2.0
	 * Responsible to delete drafts
	 * 	 
	 * @param	null
	 * @return	null
	 */	
	public function deleteDrafts()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$mainframe	= JFactory::getApplication();
		$ids		= JRequest::getVar( 'id' );
		$ids		= explode( ',' , $ids );
		$my			= JFactory::getUser();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$redirect	= EasyBlogRouter::_( 'index.php?option=com_easyblog&view=dashboard&layout=drafts' , false );
		
		if( empty( $ids ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_DRAFTS_NO_ID_ERROR' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}

		if( empty($acl->rules->delete_entry) || $my->id == 0 )
		{
			EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NO_PERMISSION_TO_DELETE_DRAFTS' ) , 'error' );
			$mainframe->redirect( $redirect );
			$mainframe->close();
		}
		
		JTable::addIncludePath( EBLOG_TABLES );
		
		foreach( $ids as $id )
		{
			$draft	= JTable::getInstance( 'Draft' , 'Table' );
			$draft->load( $id );
			
			if( $draft->created_by != $my->id )
			{
				EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NO_PERMISSION_TO_DELETE_DRAFTS' ) , 'error' );
				$mainframe->redirect( $redirect );
				$mainframe->close();
			}
			$draft->delete();
		}

		EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_DASHBOARD_DRAFTS_DISCARDED_SUCCESSFULLY' ) , 'info');
		$mainframe->redirect( $redirect );
		$mainframe->close();
	}
}