<?php
/**
 * @package		EasyBlog
 * @copyright	Copyright (C) 2010 Stack Ideas Private Limited. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 *  
 * EasyBlog is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See COPYRIGHT.php for copyright notices and details.
 */

defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.controller');

require_once( EBLOG_HELPERS . DS . 'helper.php' );
require_once( EBLOG_HELPERS . DS . 'oauth.php' );

class EasyBlogControllerOauth extends JController
{
	/**
	 * Constructor
	 *
	 * @since 0.1
	 */
	function __construct()
	{
		// Include the tables in path
		JTable::addIncludePath( EBLOG_TABLES );

		parent::__construct();
	}
	
	function request()
	{
		if(! EasyBlogHelper::isLoggedIn())
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_YOU_MUST_LOGIN_FIRST') , 'error' );
			$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog' , false ) );
			return;
		}
	
		$type		= JRequest::getCmd( 'type' );
		$config		= EasyBlogHelper::getConfig();
		$key		= $config->get( 'integrations_' . $type . '_api_key' );
		$secret		= $config->get( 'integrations_' . $type . '_secret_key' );
		$callback	= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&controller=oauth&task=grant&type=' . $type , false , true );
		$consumer	= EasyBlogOauthHelper::getConsumer( $type , $key , $secret , $callback );
		$request	= $consumer->getRequestToken();

		if( empty( $request->token ) || empty( $request->secret ) )
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_OAUTH_KEY_INVALID') , 'error');
			$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=profile' , false ) );
			return;
		}

		$oauth				=& JTable::getInstance( 'Oauth' , 'Table' );
		$oauth->user_id		= JFactory::getUser()->id;
		$oauth->type		= $type;
		$oauth->created		= JFactory::getDate()->toMySQL();
		
		// Bind the request tokens
		$param				= new JParameter('');
		$param->set( 'token' , $request->token );
		$param->set( 'secret' , $request->secret );
		
		$oauth->request_token	= $param->toString();

		$oauth->store();

		$this->setRedirect( $consumer->getAuthorizationURL( $request->token , false ) );
	}
	
	/**
	 * This will be a callback from the oauth client.
	 * @param	null
	 * @return	null	 	 
	 **/	 	
	public function grant()
	{
		$type		= JRequest::getCmd( 'type' );
		$mainframe	=& JFactory::getApplication();
		$config		= EasyBlogHelper::getConfig();
		$key		= $config->get( 'integrations_' . $type . '_api_key' );
		$secret		= $config->get( 'integrations_' . $type . '_secret_key' );
		$my			=& JFactory::getUser();

		if(! EasyBlogHelper::isLoggedIn())
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_YOU_MUST_LOGIN_FIRST') , 'error' );
			$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog' , false ) );
			return;
		}
		
		$oauth		=& JTable::getInstance( 'Oauth' , 'Table' );
		$loaded		= $oauth->loadByUser( $my->id , $type );
		
		if( !$loaded )
		{
			JError::raiseError( 500 , JText::_( 'Unable to locate any request tokens in the database for your account.' ) );
		}

		$request	= new JParameter( $oauth->request_token );
		$callback	= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&controller=oauth&task=grant&type=' . $type , false , true );
		$consumer	= EasyBlogOauthHelper::getConsumer( $type , $key , $secret , $callback );
		$verifier	= $consumer->getVerifier();

		if( empty( $verifier ) )
		{
			// Since there is a problem with the oauth authentication, we need to delete the existing record.
			$oauth->delete();
			
			JError::raiseError( 500 , JText::_( 'Invalid verifier code' ) );
		}

		$access		= $consumer->getAccess( $request->get( 'token' ) , $request->get( 'secret' ) , $verifier );

		if( !$access || empty( $access->token ) || empty( $access->secret ) )
		{
			// Since there is a problem with the oauth authentication, we need to delete the existing record.
			$oauth->delete();
			
			EasyBlogHelper::setMessageQueue( JText::_('There was an error when trying to retrieve your access tokens.') , 'error');
			$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=profile' , false ) );
			return;
		}
		
		$param		= new JParameter('');
		$param->set( 'token' 	, $access->token );
		$param->set( 'secret'	, $access->secret );
		
		$oauth->access_token	= $param->toString();
		$oauth->params			= $access->params;
		$oauth->store();
		
		EasyBlogHelper::setMessageQueue( JText::_('You have successfully associated your account') );
		$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=profile' , false ) );
	}

	/**
	 * Responsible to revoke access for the specific oauth client
	 * 
	 * @param	null
	 * @return	null	 	 	 
	 **/	 	
	public function revoke()
	{
		$mainframe	= JFactory::getApplication();
		$my			= JFactory::getUser();
		$url		= EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=profile' , false );
		$type		= JRequest::getWord( 'type' );
		$config		= EasyBlogHelper::getConfig();

		if(! EasyBlogHelper::isLoggedIn())
		{
			EasyBlogHelper::setMessageQueue( JText::_('COM_EASYBLOG_YOU_MUST_LOGIN_FIRST') , 'error' );
			$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog' , false ) );
			return;
		}
		
		$oauth		= JTable::getInstance( 'OAuth' , 'Table' );
		$oauth->loadByUser( $my->id , $type );
		
		// Revoke the access through the respective client first.
		$callback	= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&controller=oauth&task=grant&type=' . $type , false , true );
		$key		= $config->get( 'integrations_' . $type . '_api_key' );
		$secret		= $config->get( 'integrations_' . $type . '_secret_key' );
		$consumer	= EasyBlogOauthHelper::getConsumer( $type , $key , $secret , $callback );
		$consumer->setAccess( $oauth->access_token );
		
		if( !$consumer->revokeApp() )
		{
			EasyBlogHelper::setMessageQueue( JText::_('There was an error when trying to revoke your app.') , 'error');
			$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=profile' , false ) );
			return;
		}
		$oauth->delete();
		
		EasyBlogHelper::setMessageQueue( JText::_('Application revoked successfully.') );
		$this->setRedirect( EasyBlogRouter::_('index.php?option=com_easyblog&view=dashboard&layout=profile' , false ) );
	}
}