<?php
/**
 * @package		EasyBlog
 * @copyright	Copyright (C) 2011 Stack Ideas Private Limited. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 *  
 * EasyBlog is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See COPYRIGHT.php for copyright notices and details.
 */

defined('_JEXEC') or die('Restricted access');
require_once( EBLOG_HELPERS . DS . 'oauth.php' );

class EasyBlogSocialShareHelper
{
	/**
	 * Shares a story through 3rd party oauth clients
	 * 
	 * @param	TableBlog	$blog	A blog table object
	 * @param	string		$type	The type of oauth client
	 * 
	 * @return	boolean		True on success and false otherwise.	 	 	 	 	 
	 **/
	public function share( $blog , $type )
	{
	    
		$oauth			= JTable::getInstance( 'Oauth' , 'Table' );
		$config			= EasyBlogHelper::getConfig();
		$centralized 	= $config->get('integrations_'.JString::strtolower($type).'_centralized', false);

		if($centralized)
		{
			$centralizedUserId = $config->get('integrations_'.JString::strtolower($type).'_centralized_userid');

			if($centralizedUserId)
			{
				$oauth->loadByUser( $centralizedUserId , $type );
				$oauth->message = $config->get('main_' . strtolower( $type ) . '_message');
				$oauth->auto	= $config->get('integrations_'.JString::strtolower($type).'_centralized_auto_post');
			}
			else
			{
				return false;
			}
		}
		else
		{
			$oauth->loadByUser( $blog->created_by , $type );
		}
		
		if( !$oauth->access_token )
		{
			return false;
		}
		
		$acl = EasyBlogACLHelper::getRuleSet($blog->created_by);
		
		$rule = 'update_'.$type;
		
		// @task: If entry is already shared or automatic postings is disabled do not share this entry.
		if( $oauth->isShared( $blog->id ) || !$acl->rules->{$rule} )
		{
			return false;
		}
		
		$key	= $config->get( 'integrations_' . $type . '_api_key' );
		$secret	= $config->get( 'integrations_' . $type . '_secret_key' );
		
		$callback	= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&controller=oauth&task=grant&type=' . $type , false , true );
		$consumer	= EasyBlogOauthHelper::getConsumer( $type , $key , $secret , $callback );
	
		if( empty( $oauth->access_token ) )
		{
		    return false;
		}
		
		$consumer->setAccess( $oauth->access_token );

		if( $consumer->share( $blog, $oauth->message ) )
		{
			// @task: mark this as sent!
			$oauthPost	= JTable::getInstance( 'OauthPost' , 'Table' );
			$oauthPost->loadByOauthId( $blog->id , $oauth->id );
			$date		= JFactory::getDate();
			$oauthPost->post_id		= $blog->id;
			$oauthPost->oauth_id	= $oauth->id;
			$oauthPost->created		= $date->toMySQL();
			$oauthPost->modified	= $date->toMySQL();
			$oauthPost->sent		= $date->toMySQL();
			$oauthPost->store();
			
			return true;
		}
		return false;		
	}
	
	//kiv for the time being
	public function getLink($type, $id)
	{
		if(empty($type) || empty($id))
		{
			return false;
		}
		
		//prevent jtable is not loading incase overwritten by other component.
		JTable::addIncludePath(EBLOG_TABLES);
		
		$oauth	= JTable::getInstance( 'Oauth' , 'Table' );
		$oauth->loadByUser( $id , $type );
		
		$param		= new JParameter($oauth->params);
		$screenName = $param->get( 'screen_name', '');
		
		$acl	= EasyBlogACLHelper::getRuleSet($id);
		$rule	= 'update_'.$type;

		if(!$acl->rules->{$rule} )
		{
			return false;
		}
		
		switch($type)
		{
			case 'twitter':
				$link = empty($screenName)? '' : 'http://twitter.com/'.$screenName;
				break;
			case 'facebook':
				$link = '';
				break;
			case 'linkedin':
				$link = '';
				break;
		}
		
		return $link;
	}

	/*
	 * Determines whether the selected user has enabled autopostings
	 * 
	 * @param	int		$userId		The subject user.
	 * @param	string	$type		The type of social sharing.
	 */	 
	public function hasAutoPost( $userId , $type )
	{
		//check if centralized, then use centralized.
	    $config			= EasyBlogHelper::getConfig();
	    $centralized 	= $config->get('integrations_'.JString::strtolower($type).'_centralized', false);
		if($centralized)
		{
			$social->auto	= $config->get('integrations_'.JString::strtolower($type).'_centralized_auto_post');
	    }
		else
		{
			JTable::addIncludePath( EBLOG_TABLES );
			$social	= JTable::getInstance( 'Oauth' , 'Table' );
			$social->loadByUser( $userId , constant( 'EBLOG_OAUTH_' . JString::strtoupper( $type ) ) );	
		}
		
		return $social->auto;
	}

 /*
	 * Determines whether the selected user has associated their accounts or not
	 *
	 * @param	int		$userId		The subject user.
	 * @param	string	$type		The type of social sharing.
	 */
	public function isAssociated( $userId , $type )
	{
	    //check if centralized, then use centralized.
	    $config			= EasyBlogHelper::getConfig();
	    $centralized 	= $config->get('integrations_'.JString::strtolower($type).'_centralized', false);
		if($centralized)
		{
			$userId = $config->get('integrations_'.JString::strtolower($type).'_centralized_userid');
	    }

		JTable::addIncludePath( EBLOG_TABLES );
		$social	= JTable::getInstance( 'Oauth' , 'Table' );

		return $social->loadByUser( $userId , constant( 'EBLOG_OAUTH_' . JString::strtoupper( $type ) ) ) === true;
	}
}