<?php
/**
 * @package		EasyBlog
 * @copyright	Copyright (C) 2010 Stack Ideas Private Limited. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 *  
 * EasyBlog is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See COPYRIGHT.php for copyright notices and details.
 */

defined('_JEXEC') or die('Restricted access');

/*
 * String utilities class. 
 * 
 */   

class EasyBlogStringHelper
{

	function getLangCode()
	{
		$lang 		= &JFactory::getLanguage();
		$locale 	= $lang->getLocale();
		$langCode    = null;
		
		if(empty($locale))
		{
		    $langCode    = 'en-GB';
		}
		else
		{
		    $langTag    = $locale[0];
			$langData    = explode('.', $langTag);
			$langCode   = JString::str_ireplace('_', '-', $langData[0]);
		}
		return $langCode;
	}
	
	function getNoun( $var , $count , $includeCount = false )
	{
		$var	= ($count > 1 || $count == 0 ) ? $var . '_PLURAL' : $var . '_SINGULAR';
		
		return ( $includeCount ) ? JText::sprintf( $var , $count ) : JText::_( $var ); 
	}
	
	/*
	 * Convert string from ejax post into assoc-array 
	 * param - string
	 * return - assc-array	 	 
	 */		
	function ejaxPostToArray($params)
	{
        $post		= array();

		foreach($params as $item)
		{
			$pair   = explode('=', $item);
			
		    if( isset( $pair[ 0 ] ) && isset( $pair[ 1 ] ) )
		    {
		    	$key	= $pair[0];
		    	$value	= EasyBlogStringHelper::ejaxUrlDecode( $pair[ 1 ] );
		    	
		    	if( JString::stristr( $key , '[]' ) !== false )
		    	{
		    		$key			= JString::str_ireplace( '[]' , '' , $key );
		    		$post[ $key ][]	= EasyBlogStringHelper::ejaxUrlDecode( $value );
				}
				else
				{
			        $post[ $key ] = EasyBlogStringHelper::ejaxUrlDecode( $value );
				}
		    }
		}

		return $post;
	}	

	/*
	 * decode the encoded url string 
	 * param - string
	 * return - string	 	 
	 */
	function ejaxUrlDecode($string)
	{
		$rawStr	= urldecode( rawurldecode( $string ) );
		if( function_exists( 'html_entity_decode' ) )
		{
			return html_entity_decode($rawStr);
		}
		else
		{
			return EasyBlogStringHelper::unhtmlentities($rawStr);
		}	
	}

	/**
	 * A pior php 4.3.0 version of
	 * html_entity_decode
	 */
	function unhtmlentities($string)
	{
		// replace numeric entities
		$string = preg_replace('~&#x([0-9a-f]+);~ei', 'chr(hexdec("\\1"))', $string);
		$string = preg_replace('~&#([0-9]+);~e', 'chr("\\1")', $string);
		// replace literal entities
		$trans_tbl = get_html_translation_table(HTML_ENTITIES);
		$trans_tbl = array_flip($trans_tbl);
		return strtr($string, $trans_tbl);
	}
	
	function url2link( $string )
	{
	    $newString  = $string;
	    
	    preg_match('/\[url\="?(.*?)"?\](.*?)\[\/url\]/ms', $newString, $matches);

		$patterns   = array('/\[url\="?(.*?)"?\](.*?)\[\/url\]/ms',
							"/([\w]+:\/\/[\w-?&;#~=\.\/\@]+[\w\/])/i",
		                    "/([^\w\/])(www\.[a-z0-9\-]+\.[a-z0-9\-]+)/i");

		$replace    = array('[bbcode-url]',
							"<a target=\"_blank\" href=\"$1\" rel=\"nofollow\">$1</a>",
							"<a target=\"_blank\" href=\"http://$2\" rel=\"nofollow\">$2</a>");

		$newString	= preg_replace($patterns, $replace, $newString);
		
		//now convert back again.
		if(count($matches) > 0)
		{
			$patterns   = array('/\[bbcode\-url\]/ms');
			$replace    = array($matches[0]);
			$newString	= preg_replace($patterns, $replace, $newString);
		}
		
		return $newString;
	}
	
	function htmlAnchorLink( $URL, $string )
	{
		if ($string == '') return '';
		
		$pos = JString::strpos($URL, 'http://');
		if( $pos === false)
		{
		    $URL    = 'http://' . $URL;
		}

		$pattern 	= "/(((http[s]?:\/\/)|(www\.))(([a-z][-a-z0-9]+\.)?[a-z][-a-z0-9]+\.[a-z]+(\.[a-z]{2,2})?)\/?[a-z0-9._\/~#&=;%+?-]+[a-z0-9\/#=?]{1,1})/is";
		$newString 	= preg_replace($pattern, '<a href="$1" target="_blank">' . $string. '</a>', $URL);

		//this is not a link
		if( $newString == $URL)
		{
		    return $string;
		}

		return $newString;
	}
	
	function escape( $var )
	{
	    return htmlspecialchars( $var, ENT_COMPAT, 'UTF-8' );
	}
}