<?php
/**
 * @package		EasyBlog
 * @copyright	Copyright (C) 2010 Stack Ideas Private Limited. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 *  
 * EasyBlog is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See COPYRIGHT.php for copyright notices and details.
 */

defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

require_once( JPATH_ROOT.DS.'components'.DS.'com_easyblog'.DS.'constants.php' );
require_once( EBLOG_HELPERS . DS . 'router.php' );

class EasyBlogModelCategory extends JModel
{
	/**
	 * Category total
	 *
	 * @var integer
	 */
	var $_total = null;

	/**
	 * Pagination object
	 *
	 * @var object
	 */
	var $_pagination = null;

	/**
	 * Category data array
	 *
	 * @var array
	 */
	var $_data = null;
	
	function __construct()
	{
		parent::__construct();

		
		$mainframe	=& JFactory::getApplication();

		//$limit		= $mainframe->getUserStateFromRequest( 'com_easyblog.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
		//$limitstart = $mainframe->getUserStateFromRequest( 'com_easyblog.limitstart', 'limitstart', 0, 'int' );
		
		$limit		= ($mainframe->getCfg('list_limit') == 0) ? 5 : $mainframe->getCfg('list_limit');				
	    $limitstart = JRequest::getVar('limitstart', 0, 'REQUEST');
	    
		// In case limit has been changed, adjust it
		$limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);		

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
	}

	
	/**
	 * Method to get a pagination object for the categories
	 *
	 * @access public
	 * @return integer
	 */
	function getPagination()
	{		
		return $this->_pagination;
	}
	
	function _getParentIdsWithPost()
	{
        $db	=& $this->getDBO();
        $my =& JFactory::getUser();
	
		$query	= 'select * from `#__easyblog_category`';
		$query	.= ' where `published` = 1';
		$query	.= ' and `parent_id` = 0';
		if($my->id == 0)
		{
		    $query	.= ' and `private` = 0';
		}
		
		
		$db->setQuery($query);
		$result = $db->loadObjectList();
		
		
		$validCat   = array();
		
		if(count($result) > 0)
		{
			for($i = 0; $i < count($result); $i++)
			{
			    $item =& $result[$i];
			    
			    $item->childs = null;
			    EasyBlogHelper::buildNestedCategories($item->id, $item);
			    
		        $catIds     = array();
		        $catIds[]   = $item->id;
			    EasyBlogHelper::accessNestedCategoriesId($item, $catIds);

				$item->cnt   = $this->getTotalPostCount($catIds);
				
				if($item->cnt > 0)
				{
				    $validCat[] = $item->id;
				}
			    
			}
		}
		
		return $validCat;
	}
	
	function getCategories($sort = 'latest', $hideEmptyPost = true, $limit = 0)
	{
		$db	=& $this->getDBO();
		
		//blog privacy setting
		$my =& JFactory::getUser();
		$isBloggerMode  = EasyBlogRouter::isBloggerMode();
		
		$orderBy	= '';
		$limit		= ($limit == 0) ? $this->getState('limit') : $limit;
		$limitstart = $this->getState('limitstart');
		$limitSQL	= ' LIMIT ' . $limitstart . ',' . $limit;
		
		$andWhere   = array();
		
		$andWhere[]	= ' a.`published` = 1';
		$andWhere[]	= ' a.`parent_id` = 0';
		if($my->id == 0)
		    $andWhere[]	= ' a.`private` = 0';
		
		if($hideEmptyPost)
		{
			$arrParentIds	= $this->_getParentIdsWithPost();

			if(! empty($arrParentIds))
			{
			    $tmpParentId	= implode(',', $arrParentIds);
			    $andWhere[]		= ' a.`id` IN (' . $tmpParentId . ')';
			}
			else
			{
			    // this mean no categories fond. just return the empty result.
				if( empty($this->_pagination) )
				{
					jimport('joomla.html.pagination');
					$this->_pagination	= new JPagination( 0 , $limitstart , $limit);
				}
			    return array();
			}
			
			if($my->id == 0)
			    $andWhere[]	= ' a.`private` = 0';
			
			$this->_total   = count($arrParentIds);
		}
		else
		{
			$extra 		= ( count( $andWhere ) ? ' WHERE ' . implode( ' AND ', $andWhere ) : '' );
		
			$query	= 'SELECT a.`id` FROM ' . $db->nameQuote( '#__easyblog_category' ) . ' AS a';
			$query	.= ' LEFT JOIN '. $db->nameQuote( '#__easyblog_post' ) . ' AS b';
			$query	.= ' ON a.`id` = b.`category_id`';
			$query  .= ' AND b.`published` = ' . $db->Quote('1');
			if($my->id == 0)
			    $query .= ' AND b.`private` = ' . $db->Quote(BLOG_PRIVACY_PUBLIC);
			    
			if($isBloggerMode !== false)
                $query .= ' AND b.`created_by` = ' . $db->Quote($isBloggerMode);
			    
			$query	.= $extra;
			$query	.= ' GROUP BY a.`id`';

			$db->setQuery( $query );
			$result	= $db->loadResultArray();

			$this->_total	= count($result);

			if($db->getErrorNum())
			{
				JError::raiseError( 500, $db->stderr());
		    }
	    }
	    
		if( empty($this->_pagination) )
		{
			jimport('joomla.html.pagination');
			$this->_pagination	= new JPagination( $this->_total , $limitstart , $limit);
		}

		$extra 		= ( count( $andWhere ) ? ' WHERE ' . implode( ' AND ', $andWhere ) : '' );
				
		$query	= 'SELECT a.`id`, a.`title`, a.`alias`, COUNT(b.`id`) AS `cnt`';
		$query	.= ' FROM ' . $db->nameQuote( '#__easyblog_category' ) . ' AS `a`';
		$query	.= ' LEFT JOIN '. $db->nameQuote( '#__easyblog_post' ) . ' AS b';
		$query	.= ' ON a.`id` = b.`category_id`';
		$query  .= ' AND b.`published` = ' . $db->Quote('1');
		if($my->id == 0)
		    $query .= ' AND b.`private` = ' . $db->Quote(BLOG_PRIVACY_PUBLIC);
		$query	.= $extra;
		$query	.= ' GROUP BY a.`id`';

		
// 		if(! $hideEmptyPost)
// 			$query	.= ' GROUP BY a.`id`';
// 		else
// 			$query	.= ' GROUP BY a.`id` HAVING (COUNT(b.`id`) > 0)';

		
		
		switch($sort)
		{
			case 'popular' :
				$orderBy	= ' ORDER BY `cnt` DESC';
				break;
			case 'alphabet' :
				$orderBy = ' ORDER BY a.`title` ASC';
				break;
			case 'ordering' :
				$orderBy = ' ORDER BY a.`ordering` ASC';
				break;
			case 'latest' :																				
			default	:	
				$orderBy = ' ORDER BY a.`created` DESC';			
				break;
		}
		$query	.= $orderBy;
		$query	.= $limitSQL;

		//echo '<br><br>';
		//echo $query;
		
		$db->setQuery( $query );
		$result	= $db->loadObjectList();

		if($db->getErrorNum())
		{
			JError::raiseError( 500, $db->stderr());
	    }
	    
		return $result;					
		
	}
	
	function getTotalPostCount($catIds)
	{
		$db	=& $this->getDBO();

		//blog privacy setting
		$my =& JFactory::getUser();
		
		$isBloggerMode  = EasyBlogRouter::isBloggerMode();
		
        $categoryId = '';
        $isIdArray  = false;
        
		if(is_array($catIds))
		{
		    if(count($catIds) > 1)
		    {
			    $categoryId	= implode(',', $catIds);
			    $isIdArray  = true;
		    }
		    else
		    {
		        $categoryId	= $catIds[0];
		    }
		}
		else
		{
		    $categoryId  = $catIds;
		}
	
	
		$query	= 'SELECT COUNT(b.`id`) AS `cnt`';
		$query	.= ' FROM ' . $db->nameQuote( '#__easyblog_category' ) . ' AS `a`';
		$query	.= ' LEFT JOIN '. $db->nameQuote( '#__easyblog_post' ) . ' AS b';
		$query	.= ' ON a.`id` = b.`category_id`';
		$query  .= ' AND b.`published` = ' . $db->Quote('1');
		if($my->id == 0)
		    $query .= ' AND b.`private` = ' . $db->Quote(BLOG_PRIVACY_PUBLIC);
		if($isBloggerMode !== false)
		    $query .= ' AND b.`created_by` = ' . $db->Quote($isBloggerMode);
		    
		$query	.= ' WHERE a.`published` = 1';
		$query	.= ($isIdArray) ? ' AND a.`id` IN (' . $categoryId. ')' :  ' AND a.`id` = ' . $db->Quote($categoryId);
		$query	.= ' GROUP BY a.`id` HAVING (COUNT(b.`id`) > 0)';
		
		$db->setQuery($query);
		$result = $db->loadResultArray();
		
		if(!empty($result))
		{
		    return array_sum($result);
		}
		else
		{
		    return '0';
		}
	}
	
	function devInsertBlog($catogories)
	{
		$db	=& $this->getDBO();
		
		foreach ($catogories as $cat)
		{
			
			for($i = 1; $i <= 8; $i++)
			{ 
				$hits	= rand(10, 50);
				$vote	= rand(5, 30);
				$user	= rand(62, 66);
				
				$date	=& JFactory::getDate();
							
				$blog =& JTable::getInstance( 'Blog', 'Table' );
				
				$blog->created_by	= $user;
				$blog->modified		= $date->toMySql();
				$blog->created		= $date->toMySql();
				$blog->publish_up	= $date->toMySql();
				$blog->title		= 'Test '.$cat->title.' Blog Title' . $i;
				$blog->content		= 'Test '.$cat->title.' Blog Content'.$i.'<br />Dancho Danchev: A currently active malware campaign is taking advantage of bogus LinkedIn profiles impersonating celebrities in an attempt to trick users into clicking on links serving bogus media players.<br /><br />Dancho Danchev: A currently active malware campaign is taking advantage of bogus LinkedIn profiles impersonating celebrities in an attempt to trick users into clicking on links serving bogus media players.';
				$blog->excerpt		= 'Test '.$cat->title.' Excerpt '.$i.' Dancho Danchev: A currently active malware campaign is taking advantage of bogus LinkedIn profiles impersonating celebrities in an attempt to trick users into clicking on links serving bogus media players.';
				$blog->category_id	= $cat->id;
				$blog->published	= 1;
				$blog->vote			= $vote;
				$blog->hits			= $hits;
				
				$blog->store();			
			}
		
		}
		
	
	}
	
	/**
	 * Method to get total category created so far iregardless the status.
	 *
	 * @access public
	 * @return integer
	 */	
	function getTotalCategory( $userId = 0 )
	{
		$db		=& $this->getDBO();
		$where	= array();
		
		$query	= 'SELECT COUNT(1) FROM ' . $db->nameQuote( '#__easyblog_category' );
		
		if(! empty($userId))
		    $where[]  = '`created_by` = ' . $db->Quote($userId);
		    
		$extra 		= ( count( $where ) ? ' WHERE ' . implode( ' AND ', $where ) : '' );
		$query      = $query . $extra;
		
		$db->setQuery( $query );
		
		$result	= $db->loadResult();
	
		return (empty($result)) ? 0 : $result;
	}

	function isExist($categoryName, $excludeCatIds='0')
	{
	    $db =& $this->getDBO();
	    
	    $query  = 'SELECT COUNT(1) FROM #__easyblog_category';
		$query  .= ' WHERE `title` = ' . $db->Quote($categoryName);
		if($excludeCatIds != '0')
		    $query  .= ' AND `id` != ' . $db->Quote($excludeCatIds);
		
		$db->setQuery($query);
		$result = $db->loadResult();
		
		return (empty($result)) ? 0 : $result;
	}
	
    function isCategorySubscribedUser($categoryId, $userId, $email)
    {
		$db	=& $this->getDBO();

        $query  = 'SELECT `id` FROM `#__easyblog_category_subscription`';
        $query  .= ' WHERE `category_id` = ' . $db->Quote($categoryId);
        $query  .= ' AND (`user_id` = ' . $db->Quote($userId);
		$query  .= ' OR `email` = ' . $db->Quote($email) .')';

        $db->setQuery($query);
        $result = $db->loadResult();

        return $result;
    }

    function isCategorySubscribedEmail($categoryId, $email)
    {
		$db	=& $this->getDBO();

        $query  = 'SELECT `id` FROM `#__easyblog_category_subscription`';
        $query  .= ' WHERE `category_id` = ' . $db->Quote($categoryId);
        $query  .= ' AND `email` = ' . $db->Quote($email);

        $db->setQuery($query);
        $result = $db->loadResult();

        return $result;
    }

    function addCategorySubscription($categoryId, $email, $userId = '0', $fullname = '')
    {
    	$config =& EasyBlogHelper::getConfig();
    	$acl = EasyBlogACLHelper::getRuleSet();
		$my = JFactory::getUser();

		if($acl->rules->allow_subscription || (empty($my->id) && $config->get('main_allowguestsubscribe')))
		{
			$date       =& JFactory::getDate();
			$subscriber =& JTable::getInstance( 'CategorySubscription', 'Table' );

	        $subscriber->category_id 	= $categoryId;
	        $subscriber->email    		= $email;
	        if($userId != '0')
	            $subscriber->user_id    = $userId;

			$subscriber->fullname	= $fullname;
	        $subscriber->created  	= $date->toMySQL();
	        $subscriber->store();
		}
    }

    function updateCategorySubscriptionEmail($sid, $userid, $email)
    {
    	$config =& EasyBlogHelper::getConfig();
    	$acl = EasyBlogACLHelper::getRuleSet();
    	$my = JFactory::getUser();

		if($acl->rules->allow_subscription || (empty($my->id) && $config->get('main_allowguestsubscribe')))
		{
			$subscriber =& JTable::getInstance( 'CategorySubscription', 'Table' );
			$subscriber->load($sid);
			$subscriber->user_id  = $userid;
			$subscriber->email    = $email;
			$subscriber->store();
		}
    }
    
    function getCategorySubscribers($categoryId)
    {
        $db =& JFactory::getDBO();

        $query  = "SELECT *, 'categorysubscription' as `type` FROM `#__easyblog_category_subscription`";
        $query  .= " WHERE `category_id` = " . $db->Quote($categoryId);

        //echo $query . '<br/><br/>';

        $db->setQuery($query);
        $result = $db->loadObjectList();

        return $result;
    }
    
	function getTeamBlogCount( $catId )
	{
		$db =& JFactory::getDBO();
		$isBloggerMode  = EasyBlogRouter::isBloggerMode();

		$query	= 'select count(1) from `#__easyblog_post` as a';
		$query	.= '  inner join `#__easyblog_category` as b';
		$query	.= '    on a.`category_id` = b.`id`';
		$query	.= '    and b.`id` = ' . $db->Quote($catId);
		$query	.= '  inner join `#__easyblog_team_post` as c';
		$query	.= '    on a.`id` = c.`post_id`';
		$query	.= '  where a.`issitewide` = ' . $db->Quote('0');
		if($isBloggerMode !== false)
		    $query	.= '  and a.`created_by` = ' . $db->Quote($isBloggerMode);

		$db->setQuery($query);
		$result = $db->loadResult();

		return (empty($result)) ? '0' : $result;
	}
		
}