<?php
/**
* @package		EasyBlog
* @copyright	Copyright (C) 2010 Stack Ideas Private Limited. All rights reserved.
* @license		GNU/GPL, see LICENSE.php
* EasyBlog is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Restricted access');

jimport( 'joomla.application.component.view');
require_once( EBLOG_HELPERS . DS . 'string.php' );
require_once( EBLOG_HELPERS . DS . 'date.php' );
require_once( EBLOG_HELPERS . DS . 'comment.php' );

class EasyBlogViewDashboard extends EasyBlogView
{	
	var $err	= null;

	public function showVideoForm( $editorName )
	{
		$ajax	= new Ejax();
		$my		= JFactory::getUser();
		
		if( $my->id <= 0 )
		{
			$title		= JText::_('COM_EASYBLOG_INFO');
			$callback 	= JText::_('COM_EASYBLOG_NO_PERMISSION_TO_PUBLISH_OR_UNPUBLISH_COMMENT');
			$width		= '450';
			$height		= 'auto';
			$ajax->alert( $callback, $title, $width, $height );
			$ajax->send();
			return;
		}
		
		$theme		= new CodeThemes( true );
		$theme->set( 'editorName' , $editorName );
		$content	= $theme->fetch( 'ajax.dialog.videos.add.php' );
		
		$title	= JText::_( 'COM_EASYBLOG_DASHBOARD_WRITE_INSERT_VIDEO_DIALOG_TITLE' );
		
		$ajax->dialog( EasyBlogHelper::getHelper( 'DialogOptions' )->set( 'title' , $title )->set( 'content' , $content )->toObject() );
		
		return $ajax->send();
	}
	
	function imageBrowse()
	{
		$ajax	= new Ejax();
		$url = JURI::root() . '/index.php?option=com_media&view=images&tmpl=component&e_name=content';
		$ajax->loadUrl( $url );
		$ajax->send();
	}
	
	/**
	 * Generate proper permalink for a blog entry
	 **/	 	
	function getPermalink( $value )
	{
		$ajax			= new Ejax();
		$permalink		= EasyBlogHelper::getPermalink( $value );
		
		$ajax->assign( 'permalink-url' , $permalink );
		$ajax->script( 'sQuery( "#edit-permalink" ).show();' );
		$ajax->script( 'sQuery( "#permalink-value" ).show();' );
		$ajax->value( 'permalink-data' , $permalink );
		
		$ajax->send();
	}
	
	/*
	 * AJAX method to publish or unpublish a comment item.
	 * 	 
	 * @param	int	$id		The subject's id.
	 * @param	int	$status	The publishing status
	 * @return	string	JSON encoded string.
	 */
	public function publishComment( $ids , $status = '' )
	{
		$this->_publishComment( 'comment', $ids , $status);
	}
	
	function publishModerateComment( $ids , $status = '' )
	{
		$this->_publishComment( 'moderate', $ids , $status);
	}
	
	function _publishComment( $type, $ids , $status = '')
	{
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$ids		= explode( ',' , $ids );
		$my			= JFactory::getUser();

		if( empty( $acl->rules->manage_comment ) || $my->id == 0 )
		{
			$title		= JText::_('COM_EASYBLOG_INFO');
			$callback 	= JText::_('COM_EASYBLOG_NO_PERMISSION_TO_PUBLISH_OR_UNPUBLISH_COMMENT');
			$width		= '450';
			$height		= 'auto';
			$ajax->alert( $callback, $title, $width, $height );
			$ajax->send();
			return;
		}

		JTable::addIncludePath( EBLOG_TABLES );

		foreach( $ids as $id )
		{
			$comment	= JTable::getInstance( 'Comment' , 'Table' );
			$comment->load( $id );

			$blog		= JTable::getInstance( 'Blog' , 'Table' );
			$blog->load( $comment->post_id );

			// @rule: Test if the current browser is allowed to do this or not.
			// check if the comments belong to the blog post the browser or not.
			if( $blog->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
			{
				echo JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
				exit;
			}
			
			if( $comment->published == '2')
			{
				$type = 'moderate';
			}

			$comment->published		= !$comment->published;

			if( !empty( $status ) )
			{
				$comment->published	= $status == 'publish' ? true : false;
			}

			$comment->store();

			// @task: Send notification if neccessary
			if( $comment->published && !$comment->sent )
			{
				$comment->comment   = EasyBlogCommentHelper::parseBBCode($comment->comment);
				$comment->comment   = nl2br($comment->comment);

				//add notification to mailq
				EasyBlogCommentHelper::addNotification($comment, true);

				//update the sent flag to sent
				$comment->updateSent();
			}
			
			//display message
			$message	= $comment->published ? JText::_( 'COM_EASYBLOG_DASHBOARD_COMMENTS_COMMENT_PUBLISHED_SUCCESS' ) : JText::_( 'COM_EASYBLOG_DASHBOARD_COMMENTS_COMMENT_UNPUBLISHED_SUCCESS' );

			if( $type == 'comment' )
			{
				if( $comment->published )
				{
					$ajax->script( 'sQuery( "#publishing-' . $comment->id . ' a" ).removeClass( "icon-unpublished" ).addClass( "icon-published" ).html( "' . JText::_( 'COM_EASYBLOG_PUBLISHED' ) . '" )' );
				}
				else
				{
					$ajax->script( 'sQuery( "#publishing-' . $comment->id . ' a" ).removeClass( "icon-published" ).addClass( "icon-unpublished" ).html( "' . JText::_( 'COM_EASYBLOG_UNPUBLISHED' ) . '" )' );
				}
				

				$ajax->script( 'sQuery( "#eblog-comment-item' . $comment->id . ' .ui-inmsg").html( "' . $message . '" ).addClass( "success" );' );
			}
			else if(  $type == 'moderate' )
			{
			    $ajax->script( 'sQuery( "#moderate-publishing-' . $comment->id . '").removeClass( "ispending" ).addClass( "ispublish" ).html("'. $message .'")' );
			}
		}
		return $ajax->send();
	}
	
	/*
	 * AJAX method to edit a comment
	 *
	 * @param	int		$id		The comment subject.
	 * @return	string	JSON encoded stiring.
	 */
	public function editComment( $id )
	{
	    $config     =& EasyBlogHelper::getConfig();
	    $my			= JFactory::getUser();
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();

		if( empty( $acl->rules->manage_comment ) || $my->id == 0 )
		{
			$ajax->alert( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_EDIT_COMMENT'), JText::_('COM_EASYBLOG_INFO'), '450', 'auto' );
			return $ajax->send();
		}
		
		JTable::addIncludePath( EBLOG_TABLES );
		$comment	= JTable::getInstance( 'Comment' , 'Table' );
		$comment->load( $id );

		$blog		= JTable::getInstance( 'Blog' , 'Table' );
		$blog->load( $comment->post_id );

		// @rule: Test if the user really can edit the entry.
		if( $blog->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
		{
			echo JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			exit;
		}
		
		$tpl = new CodeThemes('dashboard');
		$tpl->set('comment'	, $comment );


		$options		  = new stdClass();
		$options->title   = JText::_('COM_EASYBLOG_DASHBOARD_EDIT_COMMENT');
		$options->content = $tpl->fetch( 'ajax.dialog.comments.edit.php' );

		$ajax->dialog( $options );
		$ajax->send();			
	}
	
	function updateComment( $post )
	{
		$ajax		= new Ejax();
		$mainframe	=& JFactory::getApplication();
		$my			=& JFactory::getUser();
	    $acl		= EasyBlogACLHelper::getRuleSet();
	    
		if(empty($acl->rules->manage_comment) || $my->id == 0)
		{
			$title		= JText::_('COM_EASYBLOG_INFO');
			$width		= '450';
			$height		= 'auto';
			$callback 	= JText::_('COM_EASYBLOG_NO_PERMISSION_TO_UPDATE_COMMENT');
			$ajax->alert( $callback, $title, $width, $height );
			$ajax->send();
			return;
		}

		$commentId	= $post['commentId']; 		
				
		array_walk($post, array($this, '_trim') );
		if(! $this->_validateFields($post))
		{
			$callBack = 'ejax.load(\'dashboard\',\'viewComment\', \''.$commentId.'\', \'edit\')';
			//$ajax->assign('name' , 'hahaha');
			
			//re open the comment edit pop up dialog
			$ajax->dialog( $this->err[0], $callBack, JText::_('COM_EASYBLOG_ERROR') , '450', 'auto');
			$ajax->send();
			return;
		}
		
		//add here so that other component with the same comment.php jtable file will not get reference.
		JTable::addIncludePath( JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_easyblog' . DS . 'tables');
		$comment =& JTable::getInstance( 'Comment', 'Table' );
		$comment->bindPost($post);

		$blog		= JTable::getInstance( 'Blog' , 'Table' );
		$blog->load( $comment->post_id );

		// Test if the current browser is allowed to do this or not.
		if( $blog->created_by != $my->id )
		{
			echo JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			exit;
		}
		
		$now	=& JFactory::getDate();
		$comment->modified	= $now->toMySql();
		
		if( $comment->store() )
		{
			//now we need to update the parent content.
			$title		= '<a href="javascript: ejax.load(\'dashboard\',\'viewComment\', \''.$comment->id.'\', \'readOnly\');">'.$comment->title.'</a>';

			$commt->comment	  = (JString::strlen($comment->comment) > 150) ? JString::substr($comment->comment, 0, 150) . '...' : $comment->comment;
			$commt->comment   = EasyBlogCommentHelper::parseBBCode($comment->comment);
			$commt->comment   = nl2br($comment->comment);
			
			$content	= '<p id="comment-content-' . $comment->id . '">';
			$content	.= $comment->comment;
			$content	.= '</p>';
			
			$ajax->assign('comment-title-'.$comment->id, $title);
			$ajax->assign('comment-content-'.$comment->id, $content);
			$ajax->assign('comment-name-'.$comment->id, $comment->name);
			
		}
		else
		{
			
			$ajax->alert( JText::_('COM_EASYBLOG_COMMENT_FAILED_TO_SAVE'),  JText::_('COM_EASYBLOG_ERROR') , '450', 'auto');
		}
		$ajax->send();		
		return;
	}
	
	function _trim(&$text)
	{
		$text = JString::trim($text);		
	}	
	
	function _validateFields($post)
	{
	    $config =& EasyBlogHelper::getConfig();
	
	    if($config->get('comment_requiretitle', 0))
	    {
			if(JString::strlen($post['title']) == 0)
			{
				$this->err[0]	= JText::_('COM_EASYBLOG_COMMENT_TITLE_IS_EMPTY');
				$this->err[1]	= 'title';
				return false;
			}
		}
		
		if(JString::strlen($post['name']) == 0)
		{			
			$this->err[0]	= JText::_('COM_EASYBLOG_COMMENT_NAME_IS_EMPTY');
			$this->err[1]	= 'name';
			return false;
		}
		
		if(JString::strlen($post['email']) == 0)
		{			
			$this->err[0]	= JText::_('COM_EASYBLOG_COMMENT_EMAIL_IS_EMPTY');
			$this->err[1]	= 'email';
			return false;
		}
		
		if(JString::strlen($post['comment']) == 0)
		{			
			$this->err[0]	= JText::_('COM_EASYBLOG_COMMENT_IS_EMPTY');
			$this->err[1]	= 'comment';
			return false;
		}	
		
		return true;
	}

	public function togglePublish( $ids , $action = '' )
	{
		// Id may come in a comma separated values.
		$ids			= explode( ',' , $ids );
		
		$ajax		= new Ejax();
		$mainframe	=& JFactory::getApplication();		
	    $acl		= EasyBlogACLHelper::getRuleSet();
		$my			= JFactory::getUser();
		
		if( empty( $acl->rules->publish_entry ) || $my->id == 0 )
		{
			$ajax->alert( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_PUBLISH_OR_UNPUBLISH_BLOG'), JText::_('COM_EASYBLOG_ERROR') , '450', 'auto');
			$ajax->send();
			return;
		}

		JTable::addIncludePath( EBLOG_TABLES );

		// Need to ensure that whatever id passed in is owned by the current browser
		foreach( $ids as $id )
		{
			$blog	= JTable::getInstance( 'Blog' , 'Table' );
			$blog->load( $id );
			
			if( $blog->created_by != $my->id && empty($acl->rules->moderate_entry))
			{
				echo JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
				exit;
			}
			$action	= empty( $action ) ? !$blog->published : $action;
			$ajax	= $this->_toggle( $blog->id , $ajax , $action );
		}

		return $ajax->send();
	}
	
	private function _toggle( $id , $ajax , $action = '' )
	{
		$my			= JFactory::getUser();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$blog		= JTable::getInstance( 'Blog' , 'Table' );
		$blog->load( $id );

		if( ( $blog->created_by != $my->id && empty($acl->rules->moderate_entry) ) || $id == 0 )
		{
			$ajax->alert( JText::_('COM_EASYBLOG_NOT_ALLOWED'), JText::_('COM_EASYBLOG_ERROR') , '450', 'auto');
			$ajax->send();
			return;
		}
		
		// @rule: Only super admin can publish a scheduled , draft or pending post
		if( ( $blog->published == POST_ID_SCHEDULED || $blog->published == POST_ID_DRAFT || $blog->published == POST_ID_PENDING ) && !EasyBlogHelper::isSiteAdmin() )
		{
			$ajax->alert( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_PUBLISH_OR_UNPUBLISH_BLOG'), JText::_('COM_EASYBLOG_ERROR') , '450', 'auto');
			$ajax->send();
			return;
		}

		$blog->published	= !$blog->published;
		
		if( !empty( $action ) )
		{
			$blog->published	= $action == 'publish' ? 1 : 0;
		}
		
		$blog->store();

		if( $blog->published )
		{
			// If new status is published, previously it was unpublished. Show unpublish stuffs now.
			$ajax->script( 'sQuery( "#publishing-' . $blog->id . ' a" ).removeClass( "icon-unpublished" ).addClass( "icon-published" ).html( "' . JText::_( 'COM_EASYBLOG_PUBLISHED' ) . '" )' );
		}
		else
		{
			// If new status is unpublished, previously it was published. Show published stuffs now.
			$ajax->script( 'sQuery( "#publishing-' . $blog->id . ' a" ).removeClass( "icon-published" ).addClass( "icon-unpublished" ).html( "' . JText::_( 'COM_EASYBLOG_UNPUBLISHED' ) . '" )' );
		}
		$message	= $blog->published ? JText::_( 'COM_EASYBLOG_DASHBOARD_ENTRIES_PUBLISHED_SUCCESS' ) : JText::_( 'COM_EASYBLOG_DASHBOARD_ENTRIES_UNPUBLISHED_SUCCESS' );
		$ajax->script( 'sQuery( "#eb-entry-' . $blog->id . ' .ui-inmsg").html( "' . $message . '" ).addClass( "success" );' );		
		return $ajax;
	}

	/**
	 * Ajax method to share content to social networks
	 * 
	 * @param	int		$blogId		The blog's id.
	 * @param	int		$oauthId	The oauth id.	 	 	 
	 **/	 	
	function ajaxSocialShare( $blogId , $type )
	{
		$ajax		= new Ejax();
		$config 	=& EasyBlogHelper::getConfig();
		$my			= JFactory::getUser();
		$userId     = $my->id;
		
		// Need to test if this is for centralized or their own social account.
		if( $config->get( 'integrations_' . $type . '_centralized' ) )
		{
			$userId     = $config->get( 'integrations_' . $type . '_centralized_userid' );
		}

		$oauth		= JTable::getInstance( 'Oauth' , 'Table' );
		$oauth->loadByUser( $userId );

		if( !$oauth->id )
		{
			$ajax->script('eblog.spinner.publish(\''.$blogId.'\', 0);');
			$ajax->alert( JText::_( 'COM_EASYBLOG_OAUTH_INVALID_ID' ) , JText::_('COM_EASYBLOG_INFO') , 450 , 'auto' );
			$ajax->send();
			return;
		}
		
		if( !$config->get( 'integrations_' . $oauth->type ) )
		{
			$ajax->script('eblog.spinner.publish(\''.$blogId.'\', 0);');
			$ajax->alert( JText::sprintf( 'COM_EASYBLOG_OAUTH_TYPE_DISABLED' , ucfirst( $oauth->type ) ) , JText::_('COM_EASYBLOG_INFO') , 450 , 'auto' );
			$ajax->send();
			return;
		}
		
	    $blog =& JTable::getInstance( 'blog', 'Table' );
		$blog->load( $blogId );
		
		if( $blog->created_by != $my->id || $my->id == 0 && !EasyBlogHelper::isSiteAdmin() )
		{
			$ajax->script('eblog.spinner.publish(\''.$blogId.'\', 0);');
			$ajax->alert( JText::_( 'COM_EASYBLOG_OAUTH_DO_NOT_OWN_ENTRY' ) , JText::_('COM_EASYBLOG_INFO') , 450 , 'auto' );
			$ajax->send();
			return;
		}
		
		$key	= $config->get( 'integrations_' . $oauth->type . '_api_key' );
		$secret	= $config->get( 'integrations_' . $oauth->type . '_secret_key' );
		
		if( empty( $key ) || empty( $secret ) )
		{
			$ajax->script('eblog.spinner.publish("'.$blogId.'", 0);');
			$ajax->alert( JText::_( 'COM_EASYBLOG_OAUTH_KEY_INVALID' ) , JText::_('COM_EASYBLOG_INFO') , 450 , 'auto' );
			$ajax->send();
			return;
		}
		
		$callback	= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&controller=oauth&task=grant&type=' . $oauth->type , false , true );
		require_once( EBLOG_HELPERS . DS . 'oauth.php' );
		$consumer	= EasyBlogOauthHelper::getConsumer( $oauth->type , $key , $secret , $callback );
		$consumer->setAccess( $oauth->access_token );
			
		if( !$consumer->share( $blog ) )
		{
			$ajax->script('eblog.spinner.publish("'.$blogId.'", 0);');
			$ajax->alert( JText::_( 'COM_EASYBLOG_OAUTH_ERROR_POSTING' ) , JText::_('COM_EASYBLOG_INFO') , 450 , 'auto' );
			$ajax->send();
			return;
		}

		// @todo: mark this as sent!
		$oauthPost	= JTable::getInstance( 'OauthPost' , 'Table' );
		$oauthPost->loadByOauthId( $blog->id , $oauth->id );
		$date		= JFactory::getDate();
		$oauthPost->post_id		= $blog->id;
		$oauthPost->oauth_id	= $oauth->id;
		$oauthPost->created		= $date->toMySQL();
		$oauthPost->modified		= $date->toMySQL();
		$oauthPost->sent		= $date->toMySQL();
		$oauthPost->store();
		
		// Update message
		$img 		= JURI::root() . '/components/com_easyblog/assets/icons/socialshare/' . JString::strtolower( $oauth->type ) . '.png';
		$ajax->script('ej("#oauth_img_' . $oauth->type . '_' . $blog->id.'").attr("src", "'.$img.'");');		
		$ajax->script('eblog.spinner.publish(\''.$blog->id.'\', 0);');
		$ajax->alert( JText::sprintf( 'COM_EASYBLOG_OAUTH_POST_SUCCESS' , ucfirst( $oauth->type ) ) , JText::_('COM_EASYBLOG_INFO') , 450 , 'auto' );
		$ajax->send();
	}
	
	/*
	 * Ajax method to edit a category item.
	 * @param	int	$categoryId		The category subject
	 * @return	string	JSON encoded string.
	 */	 
    function editCategory( $id )
    {
        $my     =& JFactory::getUser();
		$ajax	= new Ejax();
		$acl	= EasyBlogACLHelper::getRuleSet();
		$config =& EasyBlogHelper::getConfig();

		if( !$acl->rules->create_category || $my->id == 0 )
		{
			$ajax->alert( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_EDIT_CATEGORY'), JText::_('COM_EASYBLOG_INFO'), '450', 'auto' );
			return $ajax->send();;
		}
		
		$category	=& JTable::getInstance( 'ECategory' , 'Table' );
        $category->load( $id );
		
		// @rule: Make sure the category belongs to the user or if he is a super admin.
        if( $category->id && $category->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
        {
	    	$ajax->alert( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , '' , '450' );
	    	return $ajax->send();
		}
		
        // #26 do not restrict the parent category creator.
		$parentList = EasyBlogHelper::populateCategories('', '', 'select', 'parent_id', $category->parent_id);
        
		$tpl = new CodeThemes('dashboard');
		$tpl->set('category'	, $category );
		$tpl->set('config'		, $config );
		$tpl->set('parentList'	, $parentList );
		
		$options		  = new stdClass();
		$options->title   = JText::_( 'COM_EASYBLOG_DASHBOARD_CATEGORIES_DIALOG_EDIT_CATEGORY_TITLE' );
		$options->content = $tpl->fetch( 'ajax.dialog.category.edit.php' );

    	$ajax->dialog( $options );
		return $ajax->send();
    }

    function saveTag( $post )
    {
		$ajax	= new Ejax();
		$acl	= EasyBlogACLHelper::getRuleSet();
		$my		= JFactory::getUser();

		if($acl->rules->create_tag && $my->id != 0)
		{
			$callback 	= "";

			$tagId		= $post['id'];
			$tagTitle	= $post['title'];

	        //check if category already exists
		    $model  =& $this->getModel('Tags');

		    if($model->isExist($tagTitle, $tagId))
		    {
				$callback   = JText::_('COM_EASYBLOG_TAG_ALREADY_EXISTS');
		    }
		    else
		    {
				$tag	=& JTable::getInstance( 'Tag' , 'Table' );
		        $tag->load($tagId);
				
				if( $tag->created_by != $my->id )
				{
			    	$ajax->alert( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , '' , '450' );
			    	$ajax->send();		    	
			    	return;
				}
				
		        $tag->bind($post);

		        $tag->store();
		        //update html label to new category title
		        $callback   = JText::_('COM_EASYBLOG_TAG_UPDATED_SUCCESSFULLY');
		        $ajax->assign("lbl-".$tagId, $tag->title);
		    }
		}
		else
		{
			$callback = JText::_('COM_EASYBLOG_NO_PERMISSION_TO_CREATE_TAG');
		}

		//returned message
		$title		= JText::_('COM_EASYBLOG_INFO');
		$width		= '450';
		$height		= 'auto';

		$ajax->alert( $callback, $title, $width, $height );
    	$ajax->send();
    }
    
    /*
     * Ajax method to edit a tag.
     * @param	int	$tagId	The tag subject.
     * @return	string	JSON encoded string.
     */     
    function editTagDialog($tagId)
    {
        $my     =& JFactory::getUser();
		$ajax	= new Ejax();
		$acl	= EasyBlogACLHelper::getRuleSet();

		if( !$acl->rules->create_tag )
		{
			$ajax->alert( JText::_('COM_EASYBLOG_NO_PERMISSION_TO_EDIT_TAG') , JText::_('COM_EASYBLOG_INFO'), '450', 'auto' );
			return $ajax->send();
		}

		$tag	=& JTable::getInstance( 'Tag' , 'Table' );
        $tag->load($tagId);
			
		if( $tag->created_by != $my->id )
		{
	    	$ajax->alert( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , '' , '450' );
	    	return $ajax->send();
		}

		$tpl = new CodeThemes( 'dashboard' );
		$tpl->set('tag', $tag );

		$options		  = new stdClass();
		$options->title   = JText::_('COM_EASYBLOG_DASHBOARD_EDIT_TAG');
		$options->content = $tpl->fetch( 'ajax.dialog.tags.edit.php' );

    	$ajax->dialog( $options );
    	return $ajax->send();
    }
    
    function checkPublishStatus($status, $unpublishDate)
    {
        $ajax			= new Ejax();
		$txOffset		= EasyBlogDateHelper::getOffSet();

		$today   		=& JFactory::getDate();
		$unpublishing 	=& JFactory::getDate($unpublishDate, $txOffset);
		
		if ( ($unpublishing->toUnix() <= $today->toUnix()) &&  ($status == POST_ID_PUBLISHED))
		{
			$options		  = new stdClass();
			$options->title   = JText::_('COM_EASYBLOG_CONFIRMATION');

			ob_start();
			?>

			<?php echo JText::_('COM_EASYBLOG_DASHBOARD_SAVE_BLOG_EXPIRED'); ?>

			<div class="dialog-actions">
				<input type="button" value="<?php echo JText::_('COM_EASYBLOG_CANCEL');?>" class="button" id="edialog-cancel" name="edialog-cancel" onclick="eblog.editor.cancelSubmit();" />
				<input type="button" value="<?php echo JText::_('COM_EASYBLOG_YES');?>" class="button" id="edialog-submit" name="edialog-submit" onclick="eblog.editor.postSubmit();" />
			</div>
				
			<?php
			$options->content = ob_get_contents();
	        ob_end_clean();

	        $ajax->dialog($options);
		}
		else
		{
		    $ajax->script("eblog.editor.postSubmit();");
		}
    
		$ajax->send();
		return;
    }

	function saveDraft( $params , $content , $intro )
	{
		$ajax	= new Ejax();

		if(! EasyBlogHelper::isLoggedIn())
		{
			echo JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			exit;
		}
		
		$acl	= EasyBlogACLHelper::getRuleSet();
		
		if(empty($acl->rules->add_entry))
		{
			echo JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			exit;
		}

		// Try to load this draft to see if it exists
		$draft	= JTable::getInstance( 'Draft' , 'Table' );
		$draft->load( $params[ 'draft_id' ] );

		if( isset( $params[ 'id' ] ) && !empty( $params[ 'id' ] ) )
		{
			$draft->entry_id	= $params[ 'id' ];
			unset( $params[ 'id' ] );
		}

		$draft->bind( $params , true );

		$draft->intro	= $intro;
		$draft->content	= $content;

		if( isset( $params[ 'draft_id'] ) && !empty( $params[ 'draft_id' ] ) )
		{
			$draft->id	= $params[ 'draft_id' ];
		}
		$my		= JFactory::getUser();

		if( $draft->id && $draft->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
		{
			echo JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			exit;
		}

		$draft->store();

		
		$date	= EasyBlogDateHelper::dateWithOffSet( JFactory::getDate()->toMySQL() );
		$date	= EasyBlogDateHelper::toFormat( $date , '%I:%M:%S %p' );

		if( isset( $date[0] ) && $date[0] == 0 )
		{
			$date	= JString::substr( $date , 1 , JString::strlen( $date ) );
		}
		
		$ajax->assign( 'draft_status span' , JText::sprintf( 'COM_EASYBLOG_DRAFT_SAVED_TIME' , $date ) );
		$ajax->script( 'sQuery( "#draft_status" ).show();' );
		$ajax->value( 'draft_id' , $draft->id );
		$ajax->send();
		return;
		
	}

	/*
	 * Called by the quick post form to quickly save a draft post.
	 *
	 * @param	array	An array of html input key/value pair.
	 * @param	string	The content of the item
	 * @return	string	JSON encoded string
	 */	 
	function quickSaveDraft( $params , $content  )
	{
		$ajax	= new Ejax();
		$my		= JFactory::getUser();
		$acl	= EasyBlogACLHelper::getRuleSet();

		if( empty( $acl->rules->add_entry ) || $my->id == 0 )
		{
			$ajax->script( 'eblog.dashboard.quickpost.notify("error" , "' . JText::_( 'COM_EASYBLOG_NO_PERMISSION_TO_CREATE_BLOG' ) . '");' );
			$ajax->script( 'eblog.loader.doneLoading( "quickpost-loading" );' );
			return $ajax->send();
		}
		
		if( empty( $params[ 'title' ] ) || $params[ 'title' ] == JText::_( 'COM_EASYBLOG_DASHBOARD_QUICKPOST_TITLE_INSTRUCTIONS' ) )
		{
			$ajax->script( 'eblog.dashboard.quickpost.notify("error" , "' . JText::_( 'COM_EASYBLOG_DASHBOARD_QUICKPOST_NO_TITLE_ERROR' ) . '");' );
			$ajax->script( 'eblog.loader.doneLoading( "quickpost-loading" );' );
			return $ajax->send();
		}

		if( empty( $params[ 'content' ] ) )
		{
			$ajax->script( 'eblog.dashboard.quickpost.notify("error" , "' . JText::_( 'COM_EASYBLOG_DASHBOARD_QUICKPOST_NO_CONTENT_ERROR' ) . '");' );
			$ajax->script( 'eblog.loader.doneLoading( "quickpost-loading" );' );
			return $ajax->send();
		}
		
		// Try to load this draft to see if it exists
		$draft	= JTable::getInstance( 'Draft' , 'Table' );
		$draft->bind( $params , true );
		$draft->content		= $content;		
		$draft->created_by	= $my->id;
		
		$my		= JFactory::getUser();		
		$draft->store();
		
		$ajax->script( 'eblog.dashboard.quickpost.notify("success" , "' . JText::sprintf( 'COM_EASYBLOG_DASHBOARD_QUICKPOST_SAVED_DRAFT_SUCCESS' ) . '");' );
		$ajax->script( 'sQuery( "#reset-form" ).click();' );
		$ajax->script( 'eblog.editor.tag.clear("' . JText::_('COM_EASYBLOG_TAG_NO_SELECTED_TAGS') . '");' );
		$ajax->script( 'eblog.loader.doneLoading( "quickpost-loading" );' );
		return $ajax->send();
		
	}
	
	public function save( $post )
	{
		JTable::addIncludePath( EBLOG_TABLES );
		$my			= JFactory::getUser();
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config		= EasyBlogHelper::getConfig();
		
		if( empty( $acl->rules->add_entry ) || $my->id == 0 )
		{
			$ajax->script( 'eblog.dashboard.quickpost.notify("error" , "' . JText::_( 'COM_EASYBLOG_NO_PERMISSION_TO_CREATE_BLOG' ) . '");' );
			$ajax->script( 'eblog.loader.doneLoading( "quickpost-loading" );' );
			return $ajax->send();
		}
		
		if( empty( $post[ 'title' ] ) || $post[ 'title' ] == JText::_( 'COM_EASYBLOG_DASHBOARD_QUICKPOST_TITLE_INSTRUCTIONS' ) )
		{
			$ajax->script( 'eblog.dashboard.quickpost.notify("error" , "' . JText::_( 'COM_EASYBLOG_DASHBOARD_QUICKPOST_NO_TITLE_ERROR' ) . '");' );
			$ajax->script( 'eblog.loader.doneLoading( "quickpost-loading" );' );
			return $ajax->send();
		}

		if( empty( $post[ 'content' ] ) )
		{
			$ajax->script( 'eblog.dashboard.quickpost.notify("error" , "' . JText::_( 'COM_EASYBLOG_DASHBOARD_QUICKPOST_NO_CONTENT_ERROR' ) . '");' );
			$ajax->script( 'eblog.loader.doneLoading( "quickpost-loading" );' );
			return $ajax->send();
		}
		
		$blog		= JTable::getInstance( 'Blog' , 'Table' );
		$blog->bind( $post , true );
		
		// @task: Check if this user is allowed to publish blog
		$blog->published	= empty( $acl->rules->publish_entry ) ? false: true;
		$blog->ispending	= empty( $acl->rules->publish_entry ) ? true : false;
		$blog->created_by	= $my->id;
		$blog->frontpage 	= (empty($acl->rules->contribute_frontpage)) ? '0' : true;
		$blog->isnew		= $blog->published ? true : false;
		$blog->content		= $post[ 'content' ];

		// @task: We do not allow quick post to submit to team blogs
		$blog->issitewide	= true;
		
		// @task: Trigger necessary plugins
		$dispatcher = JDispatcher::getInstance();	
		$blog->introtext	= '';
		$blog->text			= '';

		$dispatcher->trigger( 'onBeforeEasyBlogSave', array( &$blog, $blog->isnew ) );			
		
		$blog->introtext	= $blog->intro;
		$blog->text			= $blog->content;
		
		if( EasyBlogHelper::getJoomlaVersion() >= '1.6')
		{
			$dispatcher->trigger('onContentBeforeSave', array('easyblog.blog', &$blog, $blog->isnew ));
		} 
		else
		{
			$dispatcher->trigger('onBeforeContentSave', array(&$blog, $blog->isnew ));
		}
			
		$blog->intro		= $blog->introtext;
		$blog->content		= nl2br( $blog->text );
		unset($blog->introtext);
		unset($blog->text);

		// @task: Check if user has permissions to set the privacy
		$blog->private		= empty( $acl->rules->enable_privacy ) ? 0 : $post[ 'private' ];
		
		if( !$blog->store() )
		{
			$ajax->script( 'eblog.dashboard.quickpost.notify("error" , "' . JText::_( 'COM_EASYBLOG_DASHBOARD_QUICKPOST_SAVE_ERROR' ) . '");' );
			$ajax->script( 'eblog.loader.doneLoading( "quickpost-loading" );' );
			return $ajax->send();
		}

		// @task: Store the tags
		$tags	= isset( $post[ 'tags' ] ) ? $post[ 'tags' ] : false;

		if( $tags )
		{
			if( $config->get( 'main_jomsocial_userpoint' ) )
			{
				$path	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
				
				if( JFile::exists( $path ) )
				{
					require_once( $path );
				}
			}

			JTable::addIncludePath( EBLOG_TABLES );
			$model		= $this->getModel( 'PostTag' );
			foreach( $tags as $tag )
			{
				if( !empty( $tag ) )
				{
					$table	= JTable::getInstance( 'Tag' , 'Table' );
					$table->load( $tag , true );
					
					if( !$table->exists( $tag ) && $acl->rules->create_tag )
					{
						$table->created_by	= $my->id;
						$table->title		= JString::trim( $tag );
						$table->created		= JFactory::getDate()->toMySQL();
						$table->store();
					}
					
					if( $config->get( 'main_jomsocial_userpoint' ) && class_exists( 'CUserPoints') )
					{
						CUserPoints::assignPoint( 'com_easyblog.tag.add' , $my->id );
					}
					
					$model->add( $table->id , $blog->id , JFactory::getDate()->toMySQL() );
				}
			}
		}

		if( $blog->ispending )
		{
			$ajax->script( 'eblog.dashboard.quickpost.notify( "info" , "' . JText::_( 'COM_EASYBLOG_DASHBOARD_QUICKPOST_SAVED_REQUIRE_MODERATION' ) . '");' );
			$ajax->script( 'sQuery( "#reset-form" ).click();' );
			$ajax->script( 'eblog.loader.doneLoading( "quickpost-loading" );' );
			return $ajax->send();		
		}

		// @task: Social sharing
		if( isset( $post[ 'socialshare' ] ) )
		{
			$allowed	= array( EBLOG_OAUTH_LINKEDIN , EBLOG_OAUTH_FACEBOOK , EBLOG_OAUTH_TWITTER );

			foreach( $post[ 'socialshare' ] as $share )
			{
				if( in_array( $share , $allowed ) && $blog->published == POST_ID_PUBLISHED && $config->get( 'integrations_' . $share ) )
				{
					EasyBlogSocialShareHelper::share( $blog , constant( 'EBLOG_OAUTH_' . JString::strtoupper( $share ) ) );
				}
			}
		}
		
		// @task: User point system integrations
		if( $blog->published == POST_ID_PUBLISHED )
		{
			if( $config->get( 'main_jomsocial_userpoint' ) )
			{
				$path	= JPATH_ROOT . DS . 'components' . DS . 'com_community' . DS . 'libraries' . DS . 'userpoints.php';
				if( JFile::exists( $path ) )
				{
					require_once( $path );
					CUserPoints::assignPoint( 'com_easyblog.blog.add' , $my->id );
				}
			}
			
			// @since 1.2
			// AlphaUserPoints
			if( EasyBlogHelper::isAUPEnabled() )
			{
				// get blog post URL
				$url = EasyBlogRouter::_('index.php?option=com_easyblog&view=entry&id='.$blog->id);
				AlphaUserPointsHelper::newpoints( 'plgaup_easyblog_add_blog', '', 'easyblog_add_blog_' . $blog->id, JText::sprintf('COM_EASYBLOG_AUP_NEW_BLOG_CREATED', $url, $blog->title) );
			}
		}

		// @task: Automatically feature a blog post
		if( $config->get('main_autofeatured', 0) && EasyBlogHelper::isFeatured('blogger', $blog->created_by) )
		{
	        if(! EasyBlogHelper::isFeatured('post', $blog->id))
	        {
	        	EasyBlogHelper::makeFeatured('post', $blog->id);
	        }
		}
		
		// @task: Send email notifications
		$blogger	= JTable::getInstance( 'Profile' , 'Table' );
		$blogger->load( $my->id );
		
		$data[ 'blogTitle' ]	= $blog->title;
		$data[ 'blogAuthor']	= $blogger->getName();
		$data[ 'blogLink' ]		= EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&view=entry&id='. $blog->id, false, true);

		$notification			= EasyBlogHelper::getNotification();

		// @task: Notify specified emails.
		if( $config->get('notification_blogadmin') )
		{
			$notification->notifyAdmins( JText::_('COM_EASYBLOG_EMAIL_TITLE_NEW_BLOG_ADDED') , '' , 'email.blog.new.php' , $data );
		}
		
		require_once( EBLOG_HELPERS . DS . 'subscription.php' );
		if( $config->get( 'notification_allmembers' ) )
		{
			EasyBlogSubscription::blogSendToAll( $blog , $data );
		}
		else
		{
		    // @task: Process all subscribed users and send them a new notification email.
            EasyBlogSubscription::processNewBlogNotification( $blog , $data , false );
		}

		// @task: Send a ping to pingomatic if necessary
		if($config->get('main_pingomatic', 0))
		{
			require_once( EBLOG_CLASSES . DS . 'pingomatic.php' );
			
			$siteURL    = EasyBlogHelper::getExternalLink('index.php?option=com_easyblog&view=entry&id=' . $blog->id, true);
			$siteTitle  = htmlspecialchars($blog->title);
			
			$pingomatic = new EasyBlogPingomatic();
			$pingomatic->ping( $siteTitle , $siteURL );
		}
		
		// @task: Add Jomsocial activities
		if( $blog->published == POST_ID_PUBLISHED )
		{
			EasyBlogHelper::addJomSocialActivityBlog( $blog, $blog->isnew );
		}
		

		$ajax->script( 'eblog.dashboard.quickpost.notify("success" , "' . JText::sprintf( 'COM_EASYBLOG_DASHBOARD_QUICKPOST_SAVED_SUCCESS' , $blog->title ) . '");' );
		$ajax->script( 'sQuery( "#reset-form" ).click();' );
		$ajax->script( 'eblog.loader.doneLoading( "quickpost-loading" );' );
		$ajax->script( 'eblog.editor.tag.clear("' . JText::_('COM_EASYBLOG_TAG_NO_SELECTED_TAGS') . '");' );
		return $ajax->send();
	}
	
	public function confirmDelete( $ids , $url )
	{
		$my			= JFactory::getUser();
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config		= EasyBlogHelper::getConfig();
		$ids		= explode( ',' , $ids );
		
		if( $my->id == 0 || empty( $acl->rules->delete_entry ) )
		{
			$options			= new stdClass();
			$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			$ajax->dialog( $options );
			return $ajax->send();
		}

		// Need to ensure that whatever id passed in is owned by the current browser
		foreach( $ids as $id )
		{
			$blog	= JTable::getInstance( 'Blog' , 'Table' );
			$blog->load( $id );
			
			if( $blog->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() && empty( $acl->rules->moderate_entry ) )
			{
				echo JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
				exit;
			}
		}
		
		$themes		= new CodeThemes( 'dashboard' );
		$themes->set( 'ids' 		, implode( ',' , $ids ) );
		$themes->set( 'redirect' 	, base64_encode( $url ) );
		
		$options			= new stdClass();
		$options->title		= JText::_( 'COM_EASYBLOG_DASHBOARD_ENTRIES_DIALOG_CONFIRM_DELETE_TITLE' );
		$options->content	= $themes->fetch( 'ajax.dialog.entries.delete.php' ); 
		$ajax->dialog( $options );
		return $ajax->send();
	}

	/*
	 * Confirmation to delete tags dialog
	 *
	 * @param   Array   $ids    An array of tag id's.
	 * @param   string  $redirect   Where the form should be redirected to.
	 *
	 */
	public function confirmDeleteTag( $ids , $url )
	{
		$my			= JFactory::getUser();
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config		= EasyBlogHelper::getConfig();
		$ids		= explode( ',' , $ids );

		if( $my->id == 0 || empty( $acl->rules->create_tag ) )
		{
			$options			= new stdClass();
			$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			$ajax->dialog( $options );
			return $ajax->send();
		}

		// Need to ensure that whatever id passed in is owned by the current browser
		foreach( $ids as $id )
		{
			$tag	= JTable::getInstance( 'Tag' , 'Table' );
			$tag->load( $id );

			if( $tag->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
			{
				EasyBlogHelper::setMessageQueue( JText::_( 'COM_EASYBLOG_NOT_ALLOWED' ) , 'error');
				$mainframe->redirect( EasyBlogRouter::_( $url , false ) );
				return;
			}
		}

		$themes		= new CodeThemes( 'dashboard' );
		$themes->set( 'id' 			, implode( ',' , $ids ) );
		$themes->set( 'redirect' 	, base64_encode( $url ) );

		$options			= new stdClass();
		$options->title		= JText::_( 'COM_EASYBLOG_DASHBOARD_TAGS_DIALOG_CONFIRM_DELETE_TITLE' );
		$options->content	= $themes->fetch( 'ajax.dialog.tag.delete.php' );
		$ajax->dialog( $options );
		return $ajax->send();
	}
	
	/*
	 * Ajax method to confirm the deletion of the category.
	 * @param	int	$id		The category subject
	 * @pram	string	$url	The url that we should redirect to once the deletion is completed.
	 * @return	string	JSON encoded string
	 */	 
	public function confirmDeleteCategory( $id , $url )
	{
		$my			= JFactory::getUser();
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config		= EasyBlogHelper::getConfig();
		
		if( $my->id == 0 || empty( $acl->rules->delete_category ) )
		{
			$options			= new stdClass();
			$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			$ajax->dialog( $options );
			return $ajax->send();
		}
		
		JTable::addIncludePath( EBLOG_TABLES );
		$category	= JTable::getInstance( 'ECategory' , 'Table' );
		$category->load( $id );

		if( $category->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() )
		{
			$options			= new stdClass();
			$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			$ajax->dialog( $options );
			return $ajax->send();
		}

		$themes		= new CodeThemes( 'dashboard' );
		$themes->set( 'id' , $id );
		$themes->set( 'redirect' , base64_encode( $url ) );
		
		$options			= new stdClass();
		$options->title		= JText::_( 'COM_EASYBLOG_DASHBOARD_CATEGORIES_DIALOG_CONFIRM_DELETE_TITLE' );
		$options->content	= $themes->fetch( 'ajax.dialog.category.delete.php' ); 
		$ajax->dialog( $options );
		return $ajax->send();
	}

	/*
	 * Ajax method to confirm the deletion of the comment.
	 * @param	int	$id		The comment subject
	 * @pram	string	$url	The url that we should redirect to once the deletion is completed.
	 * @return	string	JSON encoded string
	 */	 
	public function confirmDeleteComment( $id , $url )
	{
		$my			= JFactory::getUser();
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config		= EasyBlogHelper::getConfig();
		$ids		= explode( ',' , $id );
		
		if( $my->id == 0 || empty( $acl->rules->delete_comment ) )
		{
			$options			= new stdClass();
			$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			$ajax->dialog( $options );
			return $ajax->send();
		}
		
		JTable::addIncludePath( EBLOG_TABLES );
		foreach( $ids as $id )
		{
			$comment	= JTable::getInstance( 'Comment' , 'Table' );
			$comment->load( $id );
			
			// @rule: Check if the current browser is the author of the entry.
			if( $comment->created_by != $my->id && !EasyBlogHelper::isSiteAdmin() && empty( $acl->rules->delete_comment) )
			{
				$options			= new stdClass();
				$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
				$ajax->dialog( $options );
				return $ajax->send();
			}
		}

		$themes		= new CodeThemes( 'dashboard' );
		$themes->set( 'ids' 		, implode( ',' , $ids ) );
		$themes->set( 'redirect'		, base64_encode( $url ) );
		$options			= new stdClass();
		$options->title		= JText::_( 'COM_EASYBLOG_DASHBOARD_COMMENTS_DIALOG_CONFIRM_DELETE_TITLE' );
		$options->content	= $themes->fetch( 'ajax.dialog.comments.delete.php' ); 
		$ajax->dialog( $options );
		return $ajax->send();
	}

	/*
	 * Ajax method to confirm the deletion of the drafts.
	 * @param	int	$id		The comment subject
	 * @pram	string	$url	The url that we should redirect to once the deletion is completed.
	 * @return	string	JSON encoded string
	 */	 
	public function confirmDeleteDraft( $id )
	{
		$my			= JFactory::getUser();
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config		= EasyBlogHelper::getConfig();
		$ids		= explode( ',' , $id );
		
		if( $my->id == 0 || empty( $acl->rules->delete_entry ) )
		{
			$options			= new stdClass();
			$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			$ajax->dialog( $options );
			return $ajax->send();
		}
		
		JTable::addIncludePath( EBLOG_TABLES );
		foreach( $ids as $id )
		{
			$draft		= JTable::getInstance( 'Draft' , 'Table' );
			$draft->load( $id );
			
			// @rule: Check if the current browser is the author of the entry.
			if( $draft->created_by != $my->id )
			{
				$options			= new stdClass();
				$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
				$ajax->dialog( $options );
				return $ajax->send();
			}
		}

		$themes		= new CodeThemes( 'dashboard' );
		$themes->set( 'ids' 		, implode( ',' , $ids ) );
		
		$options			= new stdClass();
		$options->title		= JText::_( 'COM_EASYBLOG_DASHBOARD_DRAFTS_DIALOG_CONFIRM_DELETE_TITLE' );
		$options->content	= $themes->fetch( 'ajax.dialog.drafts.delete.php' ); 
		$ajax->dialog( $options );
		return $ajax->send();
	}

	/*
	 * Ajax method to confirm the deletion of the drafts.
	 * @param	int	$id		The comment subject
	 * @pram	string	$url	The url that we should redirect to once the deletion is completed.
	 * @return	string	JSON encoded string
	 */	 
	public function confirmDeleteAllDraft()
	{
		$my			= JFactory::getUser();
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config		= EasyBlogHelper::getConfig();

		if( $my->id == 0 || empty( $acl->rules->delete_entry ) )
		{
			$options			= new stdClass();
			$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			$ajax->dialog( $options );
			return $ajax->send();
		}

		$themes		= new CodeThemes( 'dashboard' );
		
		$options			= new stdClass();
		$options->title		= JText::_( 'COM_EASYBLOG_DASHBOARD_DRAFTS_DIALOG_CONFIRM_DELETE_TITLE' );
		$options->content	= $themes->fetch( 'ajax.dialog.drafts.deleteall.php' ); 
		$ajax->dialog( $options );
		return $ajax->send();
	}
	
	/*
	 * Display a dialog confirm the blog entry approvals.
	 * 
	 * @param	int		$ids		The specific blog id.
	 * @param	string	$url		The redirect url.
	 * @return	string	JSON encoded strings.
	 */
	public function confirmApproveBlog( $ids , $url )
	{
		$my			= JFactory::getUser();
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config		= EasyBlogHelper::getConfig();
		$ids		= explode( ',' , $ids );
		
		if( $my->id == 0 || empty( $acl->rules->manage_pending ) && !EasyBlogHelper::isSiteAdmin() )
		{
			$options			= new stdClass();
			$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			$ajax->dialog( $options );
			return $ajax->send();
		}
		
		// if( $this->acl->rules->manage_pending && $entry->ispending == 1 && $entry->published != 3 )
		
		JTable::addIncludePath( EBLOG_TABLES );
		foreach( $ids as $id )
		{
			$draft		= JTable::getInstance( 'Draft' , 'Table' );
			$draft->load( $id );
			
			// @rule: Check if the blog is really under pending
			if( $draft->pending_approval != 1 )
			{
				$options			= new stdClass();
				$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
				$ajax->dialog( $options );
				return $ajax->send();
			}
		}

		$themes		= new CodeThemes( 'dashboard' );
		$themes->set( 'ids' 		, implode( ',' , $ids ) );
		$themes->set( 'redirect'	, base64_encode( $url ) );
		$options			= new stdClass();
		$options->title		= JText::_( 'COM_EASYBLOG_DASHBOARD_BLOG_DIALOG_CONFIRM_APRROVE_TITLE' );
		$options->content	= $themes->fetch( 'ajax.dialog.pending.approve.php' ); 
		$ajax->dialog( $options );
		return $ajax->send();
	}

	function confirmRejectBlog( $ids )
	{
		$my			= JFactory::getUser();
		$ajax		= new Ejax();
		$acl		= EasyBlogACLHelper::getRuleSet();
		$config		= EasyBlogHelper::getConfig();
		$ids		= explode( ',' , $ids );
		
		if( $my->id == 0 || (empty( $acl->rules->manage_pending ) && empty( $acl->rules->publish_entry ) && !EasyBlogHelper::isSiteAdmin() ) )
		{
			$options			= new stdClass();
			$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
			$ajax->dialog( $options );
			return $ajax->send();
		}

		JTable::addIncludePath( EBLOG_TABLES );
		
		foreach( $ids as $id )
		{
			$blog		= JTable::getInstance( 'Draft' , 'Table' );
			$blog->load( $id );
	
			// @rule: Check if the blog is really under pending
			if( $blog->pending_approval != 1 )
			{
				$options			= new stdClass();
				$options->content	= JText::_( 'COM_EASYBLOG_NOT_ALLOWED' );
				$ajax->dialog( $options );
				return $ajax->send();
			}
		}

		$themes		= new CodeThemes( 'dashboard' );
		$themes->set( 'ids' 		, implode( ',' , $ids ) );
		$themes->set( 'redirect'	, base64_encode( 'index.php?option=com_easyblog&view=dashboard&layout=pending' ) );
		$options			= new stdClass();
		$options->title		= JText::_( 'COM_EASYBLOG_DASHBOARD_BLOG_DIALOG_CONFIRM_REJECT_TITLE' );
		$options->content	= $themes->fetch( 'ajax.dialog.blog.reject.php' );
		$ajax->dialog( $options );
		return $ajax->send();
	}
}